@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,7 +75,7 @@
 
 const int FK_MAJOR_VERSION = 2;
 const int FK_MINOR_VERSION = 8;
-const int FK_SUBMINOR_VERSION = 5;
+const int FK_SUBMINOR_VERSION = 8;
 
 #include <stdio.h>
 #include <string.h>
@@ -101,79 +99,65 @@ const int FK_SUBMINOR_VERSION = 5;
 
 #endif	// !WIN32 || _CYGWIN_GCC_
 
-//using namespace std;
-
 const int FK_UNDEFINED = -1;
 
-const double FK_EPS = 1.0e-8;
-const double FK_PI = 3.1415926535897932;
+const double FK_EPS = 1.0e-8;	//!< 数値演算用誤差値
+const double FK_PI = 3.1415926535897932;	//!< 円周率
 
+//! オブジェクトインスタンスのタイプを表す列挙型
 enum fk_ObjectType {
-	FK_BASEOBJECT,
-	FK_IDADMIN,
-	FK_FILEIO,
-	FK_MATRIXADMIN,
-	FK_MODEL,
-	FK_DISPLAYLINK,
-	FK_SCENE,
-	FK_SHAPE,
-	FK_TOPOLOGY,
-	FK_POLYGON,
-	FK_LINE,
-	FK_POLYLINE,
-	FK_POINT,
-	FK_CIRCLE,
-	FK_SPHERE,
-	FK_BLOCK,
-	FK_CLOSEDLINE,
-	FK_PRISM,
-	FK_CONE,
-	FK_INDEXFACESET,
-	FK_LIGHT,
-	FK_BEZCURVE,
-	FK_BSPLCURVE,
-	FK_IMAGE,
-	FK_TEXCOORD,
-	FK_TEXTURE,
-	FK_RECTTEXTURE,
-	FK_TRITEXTURE,
-	FK_MESHTEXTURE,
-	FK_IFSTEXTURE,
-	FK_UNICHAR,
-	FK_UNISTR,
-	FK_TEXTIMAGE,
-	FK_COLOR,
-	FK_MATERIAL,
-	FK_MATERIALADMIN,
-	FK_DRAW,
-	FK_DRAWSET,
-	FK_RGB,
-	FK_REDRAW,
-	FK_VSCALE,
-	FK_HSCALE,
-	FK_DRAWLIST,
-	FK_PLANE,
-	FK_WINDOW,
-	FK_PICKDATA,
-	FK_PROJECTBASE,
-	FK_PERSPECTIVE,
-	FK_ORTHO,
-	FK_VERTEX,
-	FK_HALF,
-	FK_EDGE,
-	FK_LOOP,
-	FK_SOLIDBASE,
-	FK_SOLID,
-	FK_SHAPEVIEWER,
-	FK_R_VERTEX,
-	FK_R_HALF,
-	FK_R_EDGE,
-	FK_R_LOOP,
-	FK_R_SOLID,
-	FK_PARTICLE,
-	FK_PARTICLESET
+	FK_BASEOBJECT,		//!<	fk_BaseObject 型
+	FK_MATRIXADMIN,		//!<	fk_MatrixAdmin 型
+	FK_MODEL,			//!<	fk_Model 型
+	FK_DISPLAYLINK,		//!<	fk_DisplayLink 型
+	FK_SCENE,			//!<	fk_Scene 型
+	FK_SHAPE,			//!<	fk_Shape 型
+	FK_POLYGON,			//!<	fk_Polygon 型
+	FK_LINE,			//!<	fk_Line 型
+	FK_POLYLINE,		//!<	fk_Polyline 型
+	FK_POINT,			//!<	fk_Point 型
+	FK_CIRCLE,			//!<	fk_Circle 型
+	FK_SPHERE,			//!<	fk_Sphere 型
+	FK_BLOCK,			//!<	fk_Block 型
+	FK_CLOSEDLINE,		//!<	fk_Closedline 型
+	FK_PRISM,			//!<	fk_Prism 型
+	FK_CONE,			//!<	fk_Cone 型
+	FK_INDEXFACESET,	//!<	fk_IndexFaceSet 型
+	FK_LIGHT,			//!<	fk_Light 型
+	FK_BEZCURVE,		//!<	fk_BezCurve 型
+	FK_BSPLCURVE,		//!<	fk_BSplCurve 型
+	FK_IMAGE,			//!<	fk_Image 型
+	FK_TEXCOORD,		//!<	fk_TexCoord 型
+	FK_TEXTURE,			//!<	fk_Texture 型
+	FK_RECTTEXTURE,		//!<	fk_RectTexture 型
+	FK_TRITEXTURE,		//!<	fk_TriTexture 型
+	FK_MESHTEXTURE,		//!<	fk_MeshTexture 型
+	FK_IFSTEXTURE,		//!<	fk_IFSTexture 型
+	FK_UNICHAR,			//!<	fk_UniChar 型
+	FK_UNISTR,			//!<	fk_UniStr 型
+	FK_TEXTIMAGE,		//!<	fk_TextImage 型
+	FK_COLOR,			//!<	fk_Color 型
+	FK_MATERIAL,		//!<	fk_Material 型
+	FK_PALETTE,			//!<	fk_Palette 型
+	FK_PLANE,			//!<	fk_Plane 型
+	FK_WINDOW,			//!<	fk_Window 型
+	FK_PICKDATA,		//!<	fk_PickData 型
+	FK_PROJECTBASE,		//!<	fk_ProjectBase 型
+	FK_PERSPECTIVE,		//!<	fk_Perspective 型
+	FK_FRUSTUM,			//!<	fk_Frustum 型
+	FK_ORTHO,			//!<	fk_Ortho 型
+	FK_VERTEX,			//!<	fk_Vertex 型
+	FK_HALF,			//!<	fk_Half 型
+	FK_EDGE,			//!<	fk_Edge 型
+	FK_LOOP,			//!<	fk_Loop 型
+	FK_SOLID,			//!<	fk_Solid 型
+	FK_SHAPEVIEWER,		//!<	fk_ShapeViewer 型
+	FK_PARTICLE,		//!<	fk_Particle 型
+	FK_PARTICLESET		//!<	fk_ParticleSet 型
 };
 
+#ifndef FK_DOXYGEN_USER_PROCESS
+
 #ifdef NO_GL_LIBRARY
 
 enum GLenum {
@@ -207,6 +191,14 @@ typedef float			GLfloat;
 
 #endif
 
+#endif
+
+//! FK の各クラスの基盤となる基本クラス
+/*!
+ *	このクラスは、FKのユーザが利用する大半のクラスの基底クラスとなっています。
+ *	主に、インスタンスの型を管理するための機能を提供します。
+ *	\sa fk_ObjectType
+ */
 class fk_BaseObject {
 
  private:
@@ -215,9 +207,23 @@ class fk_BaseObject {
 
  public:
 
-	fk_BaseObject(fk_ObjectType argObjType = FK_BASEOBJECT);
-	void			setObjectType(const fk_ObjectType);
+	//! コンストラクタ
+	/*!
+	 *	\param[in] type インスタンスのタイプ
+	 */
+	fk_BaseObject(fk_ObjectType type = FK_BASEOBJECT);
+
+	//! タイプ取得関数
+	/*!
+	 *	インスタンスのタイプを取得します。
+	 *	\return インスタンスのタイプ
+	 */
 	fk_ObjectType	getObjectType(void) const;
+
+#ifndef FK_DOXYGEN_USER_PROCESS
+	void			SetObjectType(const fk_ObjectType type);
+#endif
+
 };
 
 #ifdef FK_DEF_STD_NAMESPACE
