@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,6 +75,8 @@
 #include <FK/Base.h>
 #include <FK/Matrix.h>
 
+#ifndef FK_DOXYGEN_USER_PROCESS
+
 class fk_SphereBoundary {
 
  private:
@@ -101,4 +101,6 @@ class fk_SphereBoundary {
 	double		getCollisionTime(const fk_SphereBoundary &);
 };
 
+#endif
+
 #endif // !__FK_BOUNDARY_HEADER__
