@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -79,18 +77,36 @@
 class fk_Half;
 class fk_Curve;
 
+//! 稜線状態を表す列挙型
 enum fk_EdgeStatus {
-	FK_NONE_EDGE,		// エラー
-	FK_UNDEF_EDGE,		// 未定義稜線
-	FK_HALFDEF_EDGE,	// 半定義稜線
-	FK_BOTHDEF_EDGE		// 両定義稜線
+	FK_NONE_EDGE,		//!< 位相の不整合
+	FK_UNDEF_EDGE,		//!< 未定義稜線
+	FK_HALFDEF_EDGE,	//!< 半定義稜線
+	FK_BOTHDEF_EDGE		//!< 両定義稜線
 };
 
+//! 幾何曲線の種類を表す列挙型
 enum fk_CurveType {
-	FK_BEZ_CURVE,
-	FK_BSPL_CURVE
+	FK_BEZ_CURVE,		//!< Bezier 曲線
+	FK_BSPL_CURVE		//!< B-Spline 曲線
 };
 
+//! ソリッドモデルの稜線位相を管理するクラス
+/*!
+ *	このクラスは、 fk_Solid によるソリッドモデルにおいて、
+ *	稜線位相に関する制御機能を提供します。
+ *	FK におけるソリッドモデルの構造については、
+ *	ユーザーズマニュアルの「形状に対する高度な操作」の章を参照して下さい。
+ *
+ *	派生クラスのうち、ID 管理については fk_Topology,
+ *	個別マテリアル設定については fk_TopologyMaterial,
+ *	属性設定については fk_Attribute を参照して下さい。
+ *
+ *	稜線に対して、幾何形状として曲線データを設定することができます。
+ *	詳細は fk_Curve, fk_BezCurve, fk_BSplCurve を参照して下さい。
+ *	\sa fk_Solid, fk_Vertex, fk_Half, fk_Loop, fk_Topology, fk_TopologyMaterial, fk_Attribute, fk_Curve, fk_BezCurve, fk_BSplCurve
+ */
+
 class fk_Edge : public fk_Topology, public fk_TopologyMaterial {
 
 	friend class		fk_Operation;
@@ -112,23 +128,77 @@ class fk_Edge : public fk_Topology, public fk_TopologyMaterial {
 	void		SwapHalf(void);
 
  public:
+	//! コンストラクタ
 	fk_Edge(int);
+	//! デストラクタ
 	~fk_Edge();
 
+	//! 初期化関数
+	/*!
+	 *	この関数は、稜線位相の初期化を行います。
+	 *	通常、ユーザがこの関数を利用することはありません。
+	 */
 	void		Init(int);
 
+	//! 左側半稜線取得関数
+	/*!
+	 *	この稜線に属する「左側」にあたる半稜線を取得します。
+	 *	\return 「左側」にあたる半稜線を表す fk_Half 型インスタンスのアドレス。
+	 */
 	fk_Half *	getLeftHalf(void) const;
+
+	//! 右側半稜線取得関数
+	/*!
+	 *	この稜線に属する「右側」にあたる半稜線を取得します。
+	 *	\return 「右側」にあたる半稜線を表す fk_Half 型インスタンスのアドレス。
+	 */
 	fk_Half *	getRightHalf(void) const;
 
+	//! 描画線幅取得関数
+	/*!
+	 *	稜線が描画される際の線幅を返します。
+	 *	\return 描画線幅
+	 */
 	double		getDrawWidth(void) const;
-	void		setDrawWidth(double);
+
+	//! 描画線幅設定関数
+	/*!
+	 *	稜線を描画する際の線幅を設定します。
+	 *	ここでの単位は「ピクセル」となります。
+	 *	カメラからの距離に関係なく、同一の幅で描画されます。
+	 *	また、設定した幅で実際に描画されるかどうかは
+	 *	グラフィックスハードウェアの機能に依存します。
+	 *	\param[in] width	描画線幅
+	 */
+	void		setDrawWidth(double width);
+
+	//! 幾何曲線形状設定関数
+	/*!
+	 *	任意の自由曲線を幾何曲線として稜線に設定します。
+	 * 	FK には既に Bezier 曲線 (fk_BezCurve) と
+	 * 	B-Spline 曲線 (fk_BSplCurve) が標準で実装されていますが、
+	 *	fk_Curve の条件を満たせばユーザによる自作クラスも設定することができます。
+	 *	条件については fk_Curve を参照して下さい。
+	 *	\param[in] curve	幾何曲線インスタンスのアドレス
+	 */
+	void		setCurveGeometry(fk_Curve *curve);
+
+	//! 幾何曲線形状取得関数
+	/*!
+	 * 	稜線に設定されている自由曲線を取得します。
+	 *	\return 自由曲線インスタンスのアドレス。
+	 *	設定されていなかった場合は NULL を返します。
+	 */
+	fk_Curve *	getCurveGeometry(void);
+
+#ifndef FK_DOXYGEN_USER_PROCESS
 
 	void		Print(void) const;
 	bool		Check(void) const;
 	bool		Compare(fk_Edge *) const;
 
-	void		setCurveGeometry(fk_Curve *);
-	fk_Curve *	getCurveGeometry(void);
+#endif
+
 };
 
 #endif // !__FK_EDGE_HEADER__
