@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -82,6 +80,17 @@
 #define FK_EXTERN extern
 #endif // FK_MATPALCODE
 
+/*! @file MatExample.h
+	デフォルトマテリアル
+*/
+
+/*! デフォルトマテリアル変数の初期化
+	この関数は、最初から用意されているマテリアル用変数の初期化を行います。
+	これを行わないと、各変数に適切な値が入力されません。
+	この関数を呼んだあとに、各変数のマテリアル要素を設定しなおすことが可能です。
+	その後改めて初期化するには、再度この関数を呼んで下さい。
+	@return なし
+*/
 void fk_InitMaterial(void);
 
 FK_EXTERN fk_Material LightCyan;
