@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,34 +75,128 @@
 #include <FK/Material.h>
 #include <vector>
 
+//! マテリアルモード型
 typedef unsigned char	fk_MaterialMode;
-const fk_MaterialMode	FK_CHILD_MODE = 1;
-const fk_MaterialMode	FK_PARENT_MODE = 2;
-const fk_MaterialMode	FK_NONE_MODE = 3;
+
+const fk_MaterialMode	FK_CHILD_MODE = 1;		//!< 個別設定モード
+const fk_MaterialMode	FK_PARENT_MODE = 2;		//!< モデル設定モード
+const fk_MaterialMode	FK_NONE_MODE = 3;		//!< 不描画モード
+
+//! マテリアルパレットを管理するクラス
+/*!
+ *	このクラスは、マテリアルパレットを制御する機能を提供します。
+ *	「マテリアルパレット」とは、複数のマテリアルを管理するデータベースのことです。
+ *	水彩や油彩で使う「パレット」のような機能を保持しており、
+ *	複数のマテリアルを登録することができます。
+ *
+ *	\sa fk_Material, fk_Color, fk_Shape
+ */
 
 class fk_Palette : public fk_BaseObject {
  private:
-	fk_Material					thisMaterial;
 	int							thisColorID;
 	std::vector<fk_Material>	paletteStack;
 
  public:
+
+	//! コンストラクタ
 	fk_Palette(void);
+
+	//! デストラクタ
 	~fk_Palette();
 
+	//! 初期化関数
+	/*!
+	 *	パレットを初期化します。
+	 */
 	void						clearMaterial(void);
 
-	void						setObjMaterial(fk_Material *);
-	void						setObjMaterialID(int);
-	void						pushPalette(fk_Material *);
-	void						setPalette(fk_Material *, int);
-	fk_Material *				getObjMaterial(void);
+	//! オブジェクトマテリアル ID 設定関数
+	/*!
+	 *	オブジェクトマテリアルの ID を設定します。
+	 *	\param[in]	ID		オブジェクトマテリアルの ID。
+	 *	\sa getObjMaterialID()
+	 */
+	void						setObjMaterialID(int ID);
+
+	//! マテリアル追加関数
+	/*!
+	 *	パレットにマテリアルを新たに追加します。
+	 *	追加するマテリアルの ID は、
+	 *	この関数を呼ぶ前に getPaletteSize() 関数を呼ぶことで得られます。
+	 *	以下のコードは、マテリアルを追加しその ID を引数に代入します。
+	 *
+	 *	\code
+	 *	fk_Palette		pal;
+	 *	fk_Material		mat;
+	 *	int				id;
+	 *
+	 *	id = pal.getPaletteSize();
+	 *	pal.pushPalette(&mat);
+	 *	\endcode
+	 *
+	 *	\param[in]	mat		追加するマテリアル変数のアドレス
+	 *	\sa setPalette()
+	 */
+	void						pushPalette(fk_Material *mat);
+
+	//! マテリアル設定関数
+	/*!
+	 *	パレットに対し、対応する ID でマテリアルを設定します。
+	 *	ID の指定により、以下のように挙動が若干変わります。
+	 *	- もし ID が負であった場合は、パレットは何も変化しません。
+	 *	- もし ID で指定されているマテリアルが既にパレット中に存在する場合は、
+	 *		旧マテリアルを破棄して新しいマテリアルで上書きします。
+	 *	- もし ID が新規のものであった場合、
+	 *		その ID で新たに登録します。
+	 *	.
+	 *	\param[in]	mat		設定するマテリアル
+	 *	\param[in]	ID		マテリアルID
+	 *	\sa pushPalette()
+	 */
+	void						setPalette(fk_Material *mat, int ID);
+
+	//! オブジェクトマテリアル ID 取得関数
+	/*!
+	 *	現在設定されているオブジェクトマテリアルの ID を取得します。
+	 *	\return オブジェクトマテリアルの ID
+	 *	\sa setObjMaterialID()
+	 */
 	int							getObjMaterialID(void);
+
+	//! パレット中のマテリアル格納数取得関数
+	/*!
+	 *	現在パレットに格納されているマテリアルの数を返します。
+	 *	\return マテリアル数
+	 *	\sa pushPalette(), setPalette(), getMaterial()
+	 */
 	int							getPaletteSize(void);
-	fk_Material *				getMaterial(int);
+
+	//! マテリアル取得関数
+	/*!
+	 *	指定された id に対応するマテリアルのポインタを返します。
+	 *	id に対応するマテリアルがパレット中にない場合は、
+	 * 	デフォルト状態のマテリアルインスタンスへのポインタを返します。
+	 *	\return マテリアルのポインタ
+	 *	\sa pushPalette(), setPalette(), getPaletteSize()
+	 */
+	fk_Material *				getMaterial(int id);
+
+	//! マテリアル配列取得関数
+	/*!
+	 *	パレットに格納されているマテリアルを、
+	 *	STL の vector 配列へのポインタとして返します。
+	 *	\return マテリアル配列
+	 *	\sa getMaterial()
+	 */
 	std::vector<fk_Material> *	getMaterialVector(void);
 
+#ifndef FK_DOXYGEN_USER_PROCESS
+
 	void						Print(int, std::string = "");
+
+#endif
+
 };
 
 
