@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -80,7 +78,7 @@ int main(int, char *[])
 	double			step;
 	fk_Solid		solid;
 	fk_Scene		scene;
-	fk_Palette		palette;
+	//fk_Palette		palette;
 	fk_Vertex		*curV;
 	fk_Edge			*curE;
 	fk_DrawMode		curMode;
@@ -90,16 +88,14 @@ int main(int, char *[])
 
 
 	mainWin.end();
-	fk_InitMaterial();
+	fk_Material::initDefault();
 
 	Red.setAmbDiff(1.0, 0.0, 0.0);
 	Green.setAmbDiff(0.0, 1.0, 0.0);
 	Blue.setAmbDiff(0.0, 0.0, 1.0);
-	palette.setPalette(&Red, 0);
-	palette.setPalette(&Green, 1);
-	palette.setPalette(&Blue, 2);
-
-	solid.setPaletteData(&palette);
+	solid.setPalette(Red, 0);
+	solid.setPalette(Green, 1);
+	solid.setPalette(Blue, 2);
 
 	solid.makeSphere(10, 50.0);
 	shapeModel.setShape(&solid);
