@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -74,7 +72,7 @@
 #include <FK/DList.h>
 #include <FK/Model.h>
 #include <FK/Shape.h>
-#include <FK/IDAdmin.h>
+#include <FK/IDAdmin.H>
 
 using namespace std;
 
@@ -219,14 +217,24 @@ void fk_DisplayLink::setProjection(fk_ProjectBase *argProj)
 {
 	if(argProj == NULL) return;
 
-	if(argProj->getMode() == FK_PERSPECTIVE_MODE) {
+	switch(argProj->getMode()) {
+	  case FK_PERSPECTIVE_MODE:
 		perspective = *((fk_Perspective *)argProj);
 		proj = &perspective;
-	} else if(argProj->getMode() == FK_ORTHO_MODE) {
+		break;
+
+	  case FK_FRUSTUM_MODE:
+		frustum = *((fk_Frustum *)argProj);
+		proj = &frustum;
+		break;
+
+	  case FK_ORTHO_MODE:
 		ortho = *((fk_Ortho *)argProj);
 		proj = &ortho;
-	} else {
-		return;
+		break;
+
+	  default:
+		break;
 	}
 
 	projStatus++;
