@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,8 +70,9 @@
  *
  ****************************************************************************/
 #include <FK/DrawCache.h>
+#include <FK/LIAdmin.H>
 #include <FK/Vertex.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <algorithm>
 
 using namespace std;
@@ -309,7 +308,7 @@ void fk_DrawCache::AllCacheMake(void)
 	return;
 }
 
-void fk_DrawCache::allClear(void)
+void fk_DrawCache::AllClear_(void)
 {
 	AllDBClear_();
 	AllCacheClear();
@@ -375,16 +374,6 @@ fk_Loop * fk_DrawCache::GetNewLoopObj(int argID)
 	return retL;
 }
 
-fk_Shell * fk_DrawCache::GetNewShellObj(void)
-{
-	return GetNewShellObj_();
-}
-
-fk_Shell * fk_DrawCache::GetNewShellObj(int argID)
-{
-	return GetNewShellObj_(argID);
-}
-
 bool fk_DrawCache::DeleteVertexObj(fk_Vertex *argV)
 {
 	if(DeleteVertexObj_(argV) == false) return false;
@@ -431,16 +420,6 @@ bool fk_DrawCache::DeleteLoopObj(int argID)
 	return DeleteLoopObj(getLData(argID));
 }
 
-bool fk_DrawCache::DeleteShellObj(fk_Shell *argS)
-{
-	return DeleteShellObj_(argS);
-}
-
-bool fk_DrawCache::DeleteShellObj(int argID)
-{
-	return DeleteShellObj(getSData(argID));
-}
-
 void fk_DrawCache::PrintCache(void)
 {
 	fk_Printf("(vSize, lSize) = %d, %d", vertexArray.size(), ifsArray.size());
