@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,18 +73,18 @@
 #include "Engine_D3D.cxx"
 #else
 
-#include <FK/Engine.h>
+#include <FK/Engine.H>
 #include <FK/Scene.h>
 #include <FK/Light.h>
 #include <FK/Plane.h>
 #include <FK/PickData.h>
 #include <FK/Projection.h>
-#include <FK/PointDraw.h>
-#include <FK/LineDraw.h>
-#include <FK/FaceDraw.h>
-#include <FK/TextureDraw.h>
+#include <FK/PointDraw.H>
+#include <FK/LineDraw.H>
+#include <FK/FaceDraw.H>
+#include <FK/TextureDraw.H>
 
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -99,7 +97,7 @@ fk_GraphicsEngine::fk_GraphicsEngine(void)
 	faceDraw = new fk_FaceDraw;
 	textureDraw = new fk_TextureDraw;
 
-	curDLink = (fk_DisplayLink *)NULL;
+	curDLink = NULL;
 
 	return;
 }
@@ -120,7 +118,7 @@ void fk_GraphicsEngine::Init(int argW, int argH)
 {
 	winID = generalID;
 	generalID++;
-	curDLink = (fk_DisplayLink *)NULL;
+	curDLink = NULL;
 	dLinkStatus = FK_UNDEFINED;
 	dLinkID = FK_UNDEFINED;
 	wSize = argW;
@@ -129,12 +127,12 @@ void fk_GraphicsEngine::Init(int argW, int argH)
 	arrayState = true;
 	textureMode = false;
 
-	pointDraw->setArrayState(arrayState);
-	lineDraw->setArrayState(arrayState);
-	faceDraw->setArrayState(arrayState);
-	textureDraw->setArrayState(arrayState);
+	pointDraw->SetArrayState(arrayState);
+	lineDraw->SetArrayState(arrayState);
+	faceDraw->SetArrayState(arrayState);
+	textureDraw->SetArrayState(arrayState);
 
-	textureDraw->setBindMode(true);
+	textureDraw->SetBindMode(true);
 
 	return;
 }
@@ -150,7 +148,7 @@ void fk_GraphicsEngine::ResizeWindow(int argW, int argH)
 
 void fk_GraphicsEngine::ClearTextureMemory(void)
 {
-	textureDraw->clearTextureMemory();
+	textureDraw->ClearTextureMemory();
 	generalID++;
 	return;
 }
@@ -162,8 +160,7 @@ void fk_GraphicsEngine::SetViewPort(void)
 	glLoadIdentity();
 
 	if(curDLink == (fk_DisplayLink *)NULL) {
-		gluPerspective(40.0, (GLfloat)wSize/(GLfloat)hSize,
-					   1.0, 6000.0);
+		SetDefaultProjection();
 	} else {
 		SetProjection(curDLink->getProjection());
 	}
@@ -189,12 +186,14 @@ void fk_GraphicsEngine::SetPickViewPort(int argPixSize, int argX, int argY)
 
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
-	gluPickMatrix((GLdouble)argX, (GLdouble)(hSize - argY),
-				  (GLdouble)argPixSize, (GLdouble)argPixSize, ViewPort);
+	gluPickMatrix(GLdouble(argX),
+				  GLdouble(hSize - argY),
+				  GLdouble(argPixSize),
+				  GLdouble(argPixSize),
+				  ViewPort);
 
-	if(curDLink == (fk_DisplayLink *)NULL) {
-		gluPerspective(40.0, (GLfloat)wSize/(GLfloat)hSize,
-					   1.0, 6000.0);
+	if(curDLink == NULL) {
+		SetDefaultProjection();
 	} else {
 		SetProjection(curDLink->getProjection());
 	}
@@ -206,21 +205,48 @@ void fk_GraphicsEngine::SetPickViewPort(int argPixSize, int argX, int argY)
 	return;
 }
 
+void fk_GraphicsEngine::SetDefaultProjection(void)
+{
+	double			aspect;
+
+	aspect = GLfloat(wSize)/GLfloat(hSize);
+	gluPerspective(40.0, aspect, 1.0, 6000.0);
+}
+
+
 void fk_GraphicsEngine::SetProjection(const fk_ProjectBase *argProj)
 {
-	fk_Perspective	*Pers;
-	fk_Ortho		*Orth;
+	fk_ProjectBase	*proj;
+	fk_Perspective	*pers;
+	fk_Frustum		*frus;
+	fk_Ortho		*orth;
 
-	if(argProj->getMode() == FK_PERSPECTIVE_MODE) {
-		Pers = (fk_Perspective *)argProj;
-		gluPerspective((180.0 * Pers->getFovy())/FK_PI,
-					   (GLfloat)wSize/(GLfloat)hSize,
-					   Pers->getNear(), Pers->getFar());
-	} else {
-		Orth = (fk_Ortho *)argProj;
-		glOrtho(Orth->getLeft(), Orth->getRight(),
-				Orth->getBottom(), Orth->getTop(),
-				Orth->getNear(), Orth->getFar());
+	proj = const_cast<fk_ProjectBase *>(argProj);
+
+	switch(argProj->getMode()) {
+	  case FK_PERSPECTIVE_MODE:
+		pers = static_cast<fk_Perspective *>(proj);
+		gluPerspective((180.0 * pers->getFovy())/FK_PI,
+					   GLfloat(wSize)/GLfloat(hSize),
+					   pers->getNear(), pers->getFar());
+		break;
+
+	  case FK_FRUSTUM_MODE:
+		frus = static_cast<fk_Frustum *>(proj);
+		glFrustum(frus->getLeft(), frus->getRight(),
+				  frus->getBottom(), frus->getTop(),
+				  frus->getNear(), frus->getFar());
+		break;
+
+	  case FK_ORTHO_MODE:
+		orth = static_cast<fk_Ortho *>(proj);
+		glOrtho(orth->getLeft(), orth->getRight(),
+				orth->getBottom(), orth->getTop(),
+				orth->getNear(), orth->getFar());
+		break;
+
+	  default:
+		break;
 	}
 
 	return;
@@ -264,7 +290,7 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 	fk_Scene		*scene;
 	fk_Color		bgColor;
 
-	scene = (fk_Scene *)NULL;
+	scene = NULL;
 
 	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
 	if(resizeFlag == true || generalID > 2) {
@@ -272,20 +298,20 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 		resizeFlag = false;
 	}
 
-	if(curDLink != (fk_DisplayLink *)NULL) {
+	if(curDLink != NULL) {
 		if(dLinkID != curDLink->GetID() ||
 		   dLinkStatus != curDLink->GetProjChangeStatus()) {
 			dLinkID = curDLink->GetID();
 			dLinkStatus = curDLink->GetProjChangeStatus();
 			SetViewPort();
 			if(curDLink->getObjectType() == FK_SCENE) {
-				scene = (fk_Scene *)curDLink;
+				scene = static_cast<fk_Scene *>(curDLink);
 				scene->GetFogChangeStatus();
 				fogStatus = true;
 			}
 		} else {
 			if(curDLink->getObjectType() == FK_SCENE) {
-				scene = (fk_Scene *)curDLink;
+				scene = static_cast<fk_Scene *>(curDLink);
 				fogStatus = scene->GetFogChangeStatus();
 			}
 		}
@@ -308,7 +334,7 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 		glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
 	}
 
-	glClear((GLbitfield)(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT));
+	glClear(static_cast<GLbitfield>(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT));
 
 	glPushMatrix();
 
@@ -328,7 +354,7 @@ void fk_GraphicsEngine::SetScene(fk_Scene *argScene)
 
 void fk_GraphicsEngine::RecalcModelView(void)
 {
-	if(curDLink != (fk_DisplayLink *)NULL) {
+	if(curDLink != NULL) {
 		RecalcInhModelView(curDLink->getCamera());
 	}
 
@@ -350,7 +376,7 @@ void fk_GraphicsEngine::RecalcInhModelView(const fk_Model *argModel)
 	glRotated(180.0*MAngle.h/FK_PI, 0.0, 1.0, 0.0);
 	glTranslated(-MPos.x, -MPos.y, -MPos.z);
 
-	if(argModel->getParent() != (fk_Model *)NULL) {
+	if(argModel->getParent() != NULL) {
 		RecalcInhModelView(argModel->getParent());
 	}
 
@@ -363,13 +389,13 @@ void fk_GraphicsEngine::DrawObjs(bool argPickFlg)
 	list<fk_Model *>			*overlayList;
 	bool						lightFlag;
 
-	if(curDLink == (fk_DisplayLink *)NULL) return;
+	if(curDLink == NULL) return;
 	
 	lightFlag = DefineLight();
 
 	if(argPickFlg == true) modelArray.clear();
 
-	textureDraw->startUp();
+	textureDraw->StartUp();
 
 	modelPEnd = curDLink->GetModelList()->end();
 	for(modelP = curDLink->GetModelList()->begin();
@@ -416,7 +442,7 @@ void fk_GraphicsEngine::DrawModel(fk_Model *argModel,
 	  case FK_TRITEXTURE:
 	  case FK_MESHTEXTURE:
 	  case FK_IFSTEXTURE:
-		textureDraw->drawTextureObj(argModel, argLightFlg, argPickFlg);
+		textureDraw->DrawTextureObj(argModel, argLightFlg, argPickFlg);
 		textureMode = true;
 		break;
 
@@ -472,29 +498,32 @@ bool fk_GraphicsEngine::DefineLight(void)
 			glLightfv(LArray[LightID], GL_SPECULAR,
 					  &(LightMate->getSpecular()->col[0]));
 
-			LightShape = (fk_Light *)(*LightP)->getShape();
+			LightShape = static_cast<fk_Light *>((*LightP)->getShape());
 
 			switch(LightShape->getLightType()) {
 			  case FK_PARALLEL_LIGHT:
 				LightPos = (*LightP)->getInhVec();
-				LPosArray[0] = -(float)LightPos.x;
-				LPosArray[1] = -(float)LightPos.y;
-				LPosArray[2] = -(float)LightPos.z;
+				LPosArray[0] = float(-LightPos.x);
+				LPosArray[1] = float(-LightPos.y);
+				LPosArray[2] = float(-LightPos.z);
 				LPosArray[3] = 0.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
 				break;
 
 			  case FK_POINT_LIGHT:
 				LightPos = (*LightP)->getInhPosition();
-				LPosArray[0] = (float)LightPos.x;
-				LPosArray[1] = (float)LightPos.y;
-				LPosArray[2] = (float)LightPos.z;
+				LPosArray[0] = float(LightPos.x);
+				LPosArray[1] = float(LightPos.y);
+				LPosArray[2] = float(LightPos.z);
 				LPosArray[3] = 1.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
 				glLightf(LArray[LightID], GL_LINEAR_ATTENUATION,
 						 float(LightShape->getAttenuation(0)));
 				glLightf(LArray[LightID], GL_QUADRATIC_ATTENUATION,
 						 float(LightShape->getAttenuation(1)));
+				glLightf(LArray[LightID], GL_CONSTANT_ATTENUATION,
+						 float(LightShape->getAttenuation(2)));
+
 				glLightf(LArray[LightID], GL_SPOT_CUTOFF, 180.0);
 
 				break;
@@ -502,14 +531,14 @@ bool fk_GraphicsEngine::DefineLight(void)
 			  case FK_SPOT_LIGHT:
 				LightPos = (*LightP)->getInhPosition();
 				LightDirection = (*LightP)->getInhVec();
-				LPosArray[0] = (float)LightPos.x;
-				LPosArray[1] = (float)LightPos.y;
-				LPosArray[2] = (float)LightPos.z;
+				LPosArray[0] = float(LightPos.x);
+				LPosArray[1] = float(LightPos.y);
+				LPosArray[2] = float(LightPos.z);
 				LPosArray[3] = 1.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
-				LPosArray[0] = (float)LightDirection.x;
-				LPosArray[1] = (float)LightDirection.y;
-				LPosArray[2] = (float)LightDirection.z;
+				LPosArray[0] = float(LightDirection.x);
+				LPosArray[1] = float(LightDirection.y);
+				LPosArray[2] = float(LightDirection.z);
 				LPosArray[3] = 0.0;
 				glLightfv(LArray[LightID], GL_SPOT_DIRECTION, LPosArray);
 
@@ -517,6 +546,8 @@ bool fk_GraphicsEngine::DefineLight(void)
 						 float(LightShape->getAttenuation(0)));
 				glLightf(LArray[LightID], GL_QUADRATIC_ATTENUATION,
 						 float(LightShape->getAttenuation(1)));
+				glLightf(LArray[LightID], GL_CONSTANT_ATTENUATION,
+						 float(LightShape->getAttenuation(2)));
 				glLightf(LArray[LightID], GL_SPOT_EXPONENT,
 						 float(LightShape->getSpotExponent()));
 				glLightf(LArray[LightID], GL_SPOT_CUTOFF,
@@ -549,15 +580,15 @@ void fk_GraphicsEngine::DrawShapeObj(fk_Model *argObj,
 	}
 
 	if((DrawMode & FK_POLYMODE) != FK_NONEMODE) {
-		faceDraw->drawShapeFace(argObj, argLightFlag, DrawMode, argPickFlg);
+		faceDraw->DrawShapeFace(argObj, argLightFlag, DrawMode, argPickFlg);
 	}
 
 	if((DrawMode & FK_POINTMODE) != FK_NONEMODE) {
-		pointDraw->drawShapePoint(argObj, argPickFlg);
+		pointDraw->DrawShapePoint(argObj, argPickFlg);
 	}
 
 	if((DrawMode & FK_LINEMODE) != FK_NONEMODE) {
-		lineDraw->drawShapeLine(argObj, argPickFlg);
+		lineDraw->DrawShapeLine(argObj, argPickFlg);
 	}
 
 	if(argLightFlag == true) {
@@ -578,7 +609,7 @@ void fk_GraphicsEngine::LoadModelMatrix(fk_Model *argModel)
 	MAngle = argModel->getAngle();
 	MPos = argModel->getPosition();
 
-	if(argModel->getParent() != (fk_Model *)NULL) {
+	if(argModel->getParent() != NULL) {
 		LoadModelMatrix(argModel->getParent());
 	}
 
@@ -683,13 +714,17 @@ bool fk_GraphicsEngine::GetViewLinePos(double argX, double argY,
 	fk_HVector		inVec, outVec;
 	fk_Matrix		mat;
 	double			tmpY;
+	double			diffX, diffY;
 
 	ViewMatCalc(&mat);
 	mat.inverse();
 
 	tmpY = double(hSize) - argY - 1.0;
-	inVec.x = (argX - double(viewArray[0]))*2.0/double(viewArray[2]) - 1.0;
-	inVec.y = (tmpY - double(viewArray[1]))*2.0/double(viewArray[3]) - 1.0;
+	diffX = argX - double(viewArray[0]);
+	diffY = tmpY - double(viewArray[1]);
+
+	inVec.x = diffX*2.0/double(viewArray[2]) - 1.0;
+	inVec.y = diffY*2.0/double(viewArray[3]) - 1.0;
 	inVec.w = 1.0;
 
 	inVec.z = -1.0;
@@ -711,7 +746,7 @@ bool fk_GraphicsEngine::GetProjectPosition(double argX, double argY,
 {
 	fk_Vector		sVec, eVec;
 
-	if(curDLink == (fk_DisplayLink *)NULL) return false;
+	if(curDLink == NULL) return false;
 
 	if(generalID > 2) SetViewPort();
 
@@ -725,7 +760,7 @@ bool fk_GraphicsEngine::GetProjectPosition(double argX, double argY,
 	fk_Vector		sVec, eVec, eyeVec, cameraPos;
 	const fk_Model	*tmpCamera = curDLink->getCamera();
 
-	if(curDLink == (fk_DisplayLink *)NULL) return false;
+	if(curDLink == NULL) return false;
 
 	if(generalID > 2) SetViewPort();
 
@@ -758,7 +793,8 @@ bool fk_GraphicsEngine::GetWindowPosition(fk_Vector argPos, fk_Vector *retPos)
 	outVec /= outVec.w;
 	retPos->set(double(viewArray[0]) +
 				double(viewArray[2])*(outVec.x + 1.0)/2.0,
-				double(viewArray[1]) + double(hSize) - 1.0 -
+				double(viewArray[1]) +
+				double(hSize) - 1.0 -
 				double(viewArray[3])*(outVec.y + 1.0)/2.0,
 				(1.0 + outVec.z)/2.0);
 	return true;
@@ -767,10 +803,10 @@ bool fk_GraphicsEngine::GetWindowPosition(fk_Vector argPos, fk_Vector *retPos)
 void fk_GraphicsEngine::SetOGLPointerMode(bool argFlg)
 {
 	arrayState = argFlg;
-	pointDraw->setArrayState(arrayState);
-	lineDraw->setArrayState(arrayState);
-	faceDraw->setArrayState(arrayState);
-	textureDraw->setArrayState(arrayState);
+	pointDraw->SetArrayState(arrayState);
+	lineDraw->SetArrayState(arrayState);
+	faceDraw->SetArrayState(arrayState);
+	textureDraw->SetArrayState(arrayState);
 	return;
 }
 
@@ -781,20 +817,20 @@ bool fk_GraphicsEngine::GetOGLPointerMode(void)
 
 void fk_GraphicsEngine::SetOGLTextureBindMode(bool argFlg)
 {
-	textureDraw->setBindMode(argFlg);
+	textureDraw->SetBindMode(argFlg);
 	return;
 }
 
 bool fk_GraphicsEngine::GetOGLTextureBindMode(void)
 {
-	return textureDraw->getBindMode();
+	return textureDraw->GetBindMode();
 }
 
 bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 {
 	int	wCount, hCount;
 
-	if(argImage == (fk_Image *)NULL) return false;
+	if(argImage == NULL) return false;
 
 	if(argImage->getWidth() != wSize || argImage->getHeight() != hSize) {
 		argImage->newImage(wSize, hSize);
@@ -808,7 +844,8 @@ bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 		glReadBuffer(GL_BACK);
 	}
 	glReadPixels(0, 0, wSize, hSize,
-				 GL_RGB, GL_UNSIGNED_BYTE, (GLvoid *)&snapBuffer[0]);
+				 GL_RGB, GL_UNSIGNED_BYTE,
+				 static_cast<GLvoid *>(&snapBuffer[0]));
 
 	for(hCount = 0; hCount < hSize; hCount++) {
 		for(wCount = 0; wCount < wSize; wCount++) {
@@ -822,14 +859,15 @@ bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 	return true;
 }
 
-void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData, int argPixSize, int argMouseX, int argMouseY)
+void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
+									int argPixSize, int argMouseX, int argMouseY)
 {
 	GLint			hits;
 	unsigned int	ii;
 	int				elemID;
 	fk_ObjectType	elemType = FK_BASEOBJECT;
 
-	if(argPickData == (fk_PickData *)NULL) return;
+	if(argPickData == NULL) return;
 
 	SetPickViewPort(argPixSize, argMouseX, argMouseY);
 	RecalcModelView();
@@ -839,7 +877,7 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData, int argPixSize, in
 
 	argPickData->ClearData();
 
-	for(ii = 0; ii < (unsigned int)hits; ii++) {
+	for(ii = 0; ii < (unsigned int)(hits); ii++) {
 		switch(selectBuf[ii*5 + 4] % 3) {
 		  case 0:
 			elemType = FK_LOOP;
@@ -956,10 +994,10 @@ void fk_GraphicsEngine::gluPickMatrix(GLdouble argX, GLdouble argY,
 	GLdouble	sx, sy;
 	GLdouble	tx, ty;
 
-	sx = (GLdouble)viewport[2]/width;
-	sy = (GLdouble)viewport[3]/height;
-	tx = ((GLdouble)viewport[2] + 2.0 * ((GLdouble)viewport[0] - argX))/width;
-	ty = ((GLdouble)viewport[3] + 2.0 * ((GLdouble)viewport[1] - argY))/height;
+	sx = GLdouble(viewport[2])/width;
+	sy = GLdouble(viewport[3])/height;
+	tx = (GLdouble(viewport[2]) + 2.0 * (GLdouble(viewport[0]) - argX))/width;
+	ty = (GLdouble(viewport[3]) + 2.0 * (GLdouble(viewport[1]) - argY))/height;
 
 	m[0] = sx;	m[4] = 0.0;	 m[8] = 0.0;   m[12] = tx;
 	m[1] = 0.0;	m[5] = sy;	 m[9] = 0.0;   m[13] = ty;
