@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -82,7 +80,7 @@
 #include <FK/D3D/FaceDraw.h>
 #include <FK/D3D/TextureDraw.h>
 
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -1006,7 +1004,6 @@ void fk_GraphicsEngine::ViewMatCalc(fk_Matrix *argMat)
 	viewArray[2] = tmpVP.Width;	viewArray[3] = tmpVP.Height;
 	ref_lpD3DDEV->GetTransform(D3DTS_PROJECTION, &tmpProj);
 	ref_lpD3DDEV->GetTransform(D3DTS_VIEW, &tmpView);
-	ref_lpD3DDEV->GetTransform(D3DTS_WORLD, &tmpModel);
 
 	viewStack->Pop();
 
@@ -1014,11 +1011,10 @@ void fk_GraphicsEngine::ViewMatCalc(fk_Matrix *argMat)
 		for(ij = 0; ij < 4; ij++) {
 			projMat[ii][ij] = tmpProj[ii+ij*4];
 			viewMat[ii][ij] = tmpView[ii+ij*4];
-			modelMat[ii][ij] = tmpModel[ii+ij*4];
 		}
 	}
 
-	*argMat = projMat * viewMat* modelMat;
+	*argMat = projMat * viewMat;
 	return;
 }
 
