@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,8 +73,8 @@
 #include "FaceDraw_D3D.cxx"
 #else
 
-#include <FK/FaceDraw.h>
-#include <FK/OpenGL.h>
+#include <FK/FaceDraw.H>
+#include <FK/OpenGL.H>
 #include <FK/IndexFace.h>
 #include <FK/Solid.h>
 #include <FK/Vertex.h>
@@ -91,7 +89,7 @@ typedef list<fk_Loop *>::reverse_iterator	loopRIte;
 
 fk_FaceDraw::fk_FaceDraw(void)
 {
-	setArrayState(false);
+	SetArrayState(false);
 }
 
 fk_FaceDraw::~fk_FaceDraw()
@@ -99,13 +97,13 @@ fk_FaceDraw::~fk_FaceDraw()
 	return;
 }
 
-void fk_FaceDraw::setArrayState(bool argState)
+void fk_FaceDraw::SetArrayState(bool argState)
 {
 	arrayState = argState;
 	return;
 }
 
-void fk_FaceDraw::drawShapeFace(fk_Model *argObj, bool lightFlag,
+void fk_FaceDraw::DrawShapeFace(fk_Model *argObj, bool lightFlag,
 								fk_DrawMode argDMode, bool argPickFlag)
 {
 	fk_MaterialMode	shapeMateMode;
@@ -406,10 +404,10 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 
 	if(curMateID != argOldMateID) {
 		if(curMateID == FK_UNDEFINED) {
-			commonMateSet(argObj, argLightFlag, true);
+			CommonMateSet(argObj, argLightFlag, true);
 			retMateID = FK_UNDEFINED;
 		} else {
-			localMateSet(&((*argMatV)[curMateID]), argLightFlag);
+			LocalMateSet(&((*argMatV)[curMateID]), argLightFlag);
 			retMateID = curMateID;
 		}
 	}
@@ -493,7 +491,7 @@ void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 
 	glBegin(tmpType);
 
-	if(ifsP->colorFlg == false) commonMateSet(argObj, argLightFlag, true);
+	if(ifsP->colorFlg == false) CommonMateSet(argObj, argLightFlag, true);
 
 	for(ii = 0; ii < ifsP->faceSize; ii++) {
 		if(ifsP->colorFlg == true) {
@@ -503,10 +501,10 @@ void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 			}
 			if(curMateID != oldMateID) {
 				if(curMateID == FK_UNDEFINED) {
-					commonMateSet(argObj, argLightFlag, true);
+					CommonMateSet(argObj, argLightFlag, true);
 					oldMateID = FK_UNDEFINED;
 				} else {
-					localMateSet(&((*matV)[curMateID]),
+					LocalMateSet(&((*matV)[curMateID]),
 								 argLightFlag);
 					oldMateID = curMateID;
 				}
@@ -569,7 +567,7 @@ void fk_FaceDraw::DrawSolidFaceSmooth(fk_Model *argObj,
 
 	loopStack = solidP->GetLCache();
 
-	commonMateSet(argObj, argLightFlag, argNodeFlg);
+	CommonMateSet(argObj, argLightFlag, argNodeFlg);
 
 	glShadeModel(GL_SMOOTH);
 
@@ -631,7 +629,7 @@ void fk_FaceDraw::DrawIFSFaceSmooth(fk_Model *argObj,
 
 	ifsP = (fk_IndexFaceSet *)argObj->getShape();
 
-	commonMateSet(argObj, argLightFlag, argNodeFlag);
+	CommonMateSet(argObj, argLightFlag, argNodeFlag);
 	glShadeModel(GL_SMOOTH);
 
 	ifsP->ModifyVNorm();
@@ -721,7 +719,7 @@ void fk_FaceDraw::DrawSolidFaceNormal(fk_Model *argObj,
 
 	loopStack = solidP->GetLCache();
 
-	commonMateSet(argObj, argLightFlag, argNodeFlg);
+	CommonMateSet(argObj, argLightFlag, argNodeFlg);
 
 	glShadeModel(GL_FLAT);
 
@@ -792,7 +790,7 @@ void fk_FaceDraw::DrawIFSFaceNormal(fk_Model *argObj,
 
 	ifsP = (fk_IndexFaceSet *)argObj->getShape();
 
-	commonMateSet(argObj, argLightFlag, argNodeFlag);
+	CommonMateSet(argObj, argLightFlag, argNodeFlag);
 	glShadeModel(GL_FLAT);
 
 	ifsP->ModifyPNorm();
@@ -833,7 +831,7 @@ void fk_FaceDraw::DrawSurface(fk_Surface *)
 }
 
 
-void fk_FaceDraw::commonMateSet(fk_Model *argObj, bool lightFlag, bool matFlag)
+void fk_FaceDraw::CommonMateSet(fk_Model *argObj, bool lightFlag, bool matFlag)
 {
 	float 		tmpShininess;
 	fk_Shape	*shapeP;
@@ -866,7 +864,7 @@ void fk_FaceDraw::commonMateSet(fk_Model *argObj, bool lightFlag, bool matFlag)
 	return;
 }
 
-void fk_FaceDraw::localMateSet(fk_Material *argMaterial, bool lightFlag)
+void fk_FaceDraw::LocalMateSet(fk_Material *argMaterial, bool lightFlag)
 {
 	float tmpShininess;
 
