@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,15 +69,14 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/FileInput.h>
-#include <FK/DataBase.h>
+#include <FK/FileInput.H>
+#include <FK/DataBase.H>
 #include <FK/Palette.h>
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -120,7 +117,7 @@ fk_DataFormatMode fk_FileInput::GetMode(string argFileName)
 		return FK_ERROR_FILE;
 	}
 
-	if(bRead(&mask, 1, fp) == false) {
+	if(BRead(&mask, 1, fp) == false) {
 		fclose(fp);
 		return FK_ERROR_FILE;
 	}
@@ -212,8 +209,10 @@ bool fk_FileInput::GetShapeData_(fk_DataFormatMode argMode, FILE *argFP,
 								 bool argHeaderFlg)
 {
 	int			vSize, hSize, eSize, lSize;
+	int			majorVer, minorVer, subMinorVer;
 
-	if(argHeaderFlg == true) GetHeader(argMode, argFP);
+	if(argHeaderFlg == true) GetHeader(argMode, argFP,
+									   &majorVer, &minorVer, &subMinorVer);
 
 	GetElemNum(argMode, argFP, &vSize, &hSize, &eSize, &lSize);
 	DB->ResizeData(vSize, hSize, eSize, lSize);
@@ -238,17 +237,30 @@ bool fk_FileInput::GetShapeData_(fk_DataFormatMode argMode, FILE *argFP,
 	return true;
 }
 
-void fk_FileInput::GetHeader(fk_DataFormatMode argMode, FILE *argFP)
+void fk_FileInput::GetHeader(fk_DataFormatMode argMode, FILE *argFP,
+							 int *majorVer, int *minorVer, int *subMinorVer)
 {
-	char		buffer[512];
+	char		cBuffer[512];
+	string		line;
+	int			iBuffer[5];
 
 	switch(argMode) {
 	  case FK_TEXT_FILE:
-		fgets(buffer, 511, argFP);
-		fgets(buffer, 511, argFP);
+		fgets(cBuffer, 511, argFP);
+		fgets(cBuffer, 511, argFP);
+		line = cBuffer;
+		PopWord(&line);
+		*majorVer = Str2Int(PopWord(&line));
+		*minorVer = Str2Int(PopWord(&line));
+		*subMinorVer = Str2Int(PopWord(&line));
+
 		break;
 	  case FK_BINARY_FILE:
-		bRead((int *)buffer, 4, argFP);
+		BRead(iBuffer, 4, argFP);
+		*majorVer = iBuffer[1];
+		*minorVer = iBuffer[2];
+		*subMinorVer = iBuffer[3];
+
 		break;
 	  default:
 		break;
@@ -268,7 +280,7 @@ void fk_FileInput::GetElemNum(fk_DataFormatMode argMode, FILE *argFP,
 		sscanf(buffer, "%s%d%d%d%d", tag,
 			   argVSize, argHSize, argESize, argLSize);
 	} else {
-		bRead(sizeList, 5, argFP);
+		BRead(sizeList, 5, argFP);
 
 		*argVSize = sizeList[0];
 		*argHSize = sizeList[1];
@@ -380,10 +392,10 @@ bool fk_FileInput::GetVertexData(fk_DataFormatMode argMode,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(IDSet, 3, argFP) == false) return false;
-		if(bRead(pos, 3, argFP) == false) return false;
+		if(BRead(IDSet, 3, argFP) == false) return false;
+		if(BRead(pos, 3, argFP) == false) return false;
 		if(sizeMode == true) {
-			if(bRead(&size, 1, argFP) == false) return false;
+			if(BRead(&size, 1, argFP) == false) return false;
 		}
 
 		break;
@@ -417,7 +429,7 @@ bool fk_FileInput::GetHalfData(fk_DataFormatMode argMode,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(IDSet, 4, argFP) == false) return false;
+		if(BRead(IDSet, 4, argFP) == false) return false;
 		break;
 
 	  default:
@@ -449,9 +461,9 @@ bool fk_FileInput::GetEdgeData(fk_DataFormatMode argMode,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(IDSet, 4, argFP) == false) return false;
+		if(BRead(IDSet, 4, argFP) == false) return false;
 		if(sizeMode == true) {
-			if(bRead(&width, 1, argFP) == false) return false;
+			if(BRead(&width, 1, argFP) == false) return false;
 		}
 		break;
 
@@ -479,7 +491,7 @@ bool fk_FileInput::GetLoopData(fk_DataFormatMode argMode,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(IDSet, 3, argFP) == false) return false;
+		if(BRead(IDSet, 3, argFP) == false) return false;
 		break;
 
 	  default:
@@ -558,7 +570,7 @@ bool fk_FileInput::GetAdminHeader(fk_DataFormatMode argMode, FILE *argFP,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(sizeSet, 2, argFP) == false) return false;
+		if(BRead(sizeSet, 2, argFP) == false) return false;
 
 		*argListSize = sizeSet[0];
 		*argFlagSize = sizeSet[1];
@@ -593,7 +605,7 @@ bool fk_FileInput::GetAdminEraseList(fk_DataFormatMode argMode, FILE *argFP,
 		if(argSize == 0) break;
 		array = new int [argSize];
 
-		if(bRead(array, argSize, argFP) == false) {
+		if(BRead(array, argSize, argFP) == false) {
 			delete [] array;
 			argAdmin->Init(1);
 			return false;
@@ -734,7 +746,12 @@ bool fk_FileInput::SetLoopData(int argLID, int argMateID, int argMateMode,
 bool fk_FileInput::GetPaletteData_(fk_DataFormatMode argMode, FILE *argFP,
 								   bool argHeaderFlg)
 {
-	if(argHeaderFlg == true) GetHeader(argMode, argFP);
+	int		majorVer, minorVer, subMinorVer;
+
+	if(argHeaderFlg == true) {
+		GetHeader(argMode, argFP, &majorVer, &minorVer, &subMinorVer);
+	}
+
 	if(GetMainMaterialData(argMode, argFP) == false) return false;
 	if(GetSubMaterialData(argMode, argFP) == false) return false;
 	return true;
@@ -761,7 +778,7 @@ bool fk_FileInput::GetMainMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(valSet, 2, argFP) == false) return false;
+		if(BRead(valSet, 2, argFP) == false) return false;
 		if(valSet[0] < -1 || valSet[1] < 0) return false;
 		break;
 
@@ -771,11 +788,11 @@ bool fk_FileInput::GetMainMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 
 	palette->setObjMaterialID(valSet[0]);
 	palStack->resize(valSet[1]);
-	
+
 	if(GetMaterialData(argMode, argFP, &localMat) == false) {
 		return false;
 	}
-	palette->setObjMaterial(&localMat);
+
 	return true;
 }
 
@@ -831,9 +848,9 @@ bool fk_FileInput::GetMaterialData(fk_DataFormatMode argMode,
 		break;
 
 	  case FK_BINARY_FILE:
-		if(bRead(&a, 1, argFP) == false) return false;
-		if(bRead(val, 12, argFP) == false) return false;
-		if(bRead(&shininess, 1, argFP) == false) return false;
+		if(BRead(&a, 1, argFP) == false) return false;
+		if(BRead(val, 12, argFP) == false) return false;
+		if(BRead(&shininess, 1, argFP) == false) return false;
 		
 		argMat->setAlpha(a);
 		argMat->setAmbient(val[0], val[1], val[2]);
