@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,16 +70,16 @@
  *
  ****************************************************************************/
 #include <FK/IFSTexture.h>
-#include <FK/MQOParser.h>
-#include <FK/D3DXParser.h>
-#include <FK/Error.h>
+#include <FK/MQOParser.H>
+#include <FK/D3DXParser.H>
+#include <FK/Error.H>
 
 using namespace std;
 
 fk_IFSTexture::fk_IFSTexture(fk_Image *argImage)
 	: fk_Texture(argImage)
 {
-	setObjectType(FK_IFSTEXTURE);
+	SetObjectType(FK_IFSTEXTURE);
 	ifs = new fk_IndexFaceSet;
 	coordArray.clear();
 	setImage(argImage);
@@ -168,9 +166,9 @@ bool fk_IFSTexture::readMQOFile(string argFileName,
 	fk_MQOParser		*mqoParser = new fk_MQOParser();
 	bool				retVal;
 
-	mqoParser->setIFSTexture(this);
-	mqoParser->setContMode(argContFlg);
-	retVal = mqoParser->readMQOFile(argFileName, argObjName, argMateID, true);
+	mqoParser->SetIFSTexture(this);
+	mqoParser->SetContMode(argContFlg);
+	retVal = mqoParser->ReadMQOFile(argFileName, argObjName, argMateID, true);
 	delete mqoParser;
 
 	if(retVal == false) return false;
@@ -187,9 +185,9 @@ bool fk_IFSTexture::readMQOData(unsigned char *argBuffer,
 	fk_MQOParser		*mqoParser = new fk_MQOParser();
 	bool				retVal;
 
-	mqoParser->setIFSTexture(this);
-	mqoParser->setContMode(argContFlg);
-	retVal = mqoParser->readMQOData(argBuffer, argObjName, argMateID, true);
+	mqoParser->SetIFSTexture(this);
+	mqoParser->SetContMode(argContFlg);
+	retVal = mqoParser->ReadMQOData(argBuffer, argObjName, argMateID, true);
 	delete mqoParser;
 
 	if(retVal == false) return false;
@@ -205,8 +203,8 @@ bool fk_IFSTexture::readD3DXFile(string argFileName, string argObjName,
 	fk_D3DXParser		*d3dxParser = new fk_D3DXParser();
 	bool				retVal;
 
-	d3dxParser->setIFSTexture(this);
-	retVal = d3dxParser->readD3DXFile(argFileName, argObjName,
+	d3dxParser->SetIFSTexture(this);
+	retVal = d3dxParser->ReadD3DXFile(argFileName, argObjName,
 									  argMateID, true);
 
 	setAnimationTime(-1.0);
@@ -225,11 +223,6 @@ bool fk_IFSTexture::getConnectMode(void)
 	return connectMode;
 }
 
-vector< vector<int> > * fk_IFSTexture::getCommonList(void)
-{
-	return &commonList;
-}
-
 void fk_IFSTexture::SetConnectNormal(void)
 {
 	unsigned int			i, j;
