@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,16 +69,16 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/IFSetHandle.h>
+#include <FK/IFSetHandle.H>
 
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/DataBase.h>
+#include <FK/DataBase.H>
 #include <FK/Reference.h>
 
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -127,7 +125,7 @@ bool fk_IFSetHandle::SetIndexFaceSet(vector<fk_Vector> *vData,
 	}
 
 	if(argSolidFlag == true) {
-		if(refineTopology() == false) {
+		if(RefineTopology() == false) {
 			DB->AllClear();
 			return false;
 		}
@@ -334,7 +332,7 @@ bool fk_IFSetHandle::DefineNewEH(int vID1, int vID2, fk_IFS_EdgeSet *VPair,
 	return true;
 }
 
-bool fk_IFSetHandle::refineTopology(void)
+bool fk_IFSetHandle::RefineTopology(void)
 {
 	fk_Half	*CurHalf;
 
