@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,8 +70,13 @@
  *
  ****************************************************************************/
 #include <FK/Image.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
+
+#ifdef _FREEBSD_
+#include <FL/images/png.h>
+#else
 #include <libpng/png.h>
+#endif
 
 using namespace std;
 
@@ -82,7 +85,11 @@ extern "C" {
 	#ifdef WIN32
 		#define HAVE_BOOLEAN
 	#endif
-	#include "jpeg/jpeglib.h"
+	#ifdef _FREEBSD_
+		#include <FL/images/jpeglib.h>
+	#else
+		#include "jpeg/jpeglib.h"
+	#endif
 }
 
 bool fk_Image::IsBmpFile(const string argFName) const
