@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,20 +71,20 @@
  ****************************************************************************/
 #include <FK/IndexFace.h>
 #include <FK/Solid.h>
-#include <FK/D3DXAnimation.h>
-#include <FK/D3DXParser.h>
-#include <FK/SMFParser.h>
-#include <FK/STLParser.h>
-#include <FK/HRCParser.h>
-#include <FK/RDSParser.h>
-#include <FK/DXFParser.h>
-#include <FK/VRMLParser.h>
-#include <FK/MQOParser.h>
-#include <FK/VRMLOut.h>
-#include <FK/STLOut.h>
-#include <FK/DXFOut.h>
-#include <FK/MQOOut.h>
-#include <FK/IFSetHandle.h>
+#include <FK/D3DXAnimation.H>
+#include <FK/D3DXParser.H>
+#include <FK/SMFParser.H>
+#include <FK/STLParser.H>
+#include <FK/HRCParser.H>
+#include <FK/RDSParser.H>
+#include <FK/DXFParser.H>
+#include <FK/VRMLParser.H>
+#include <FK/MQOParser.H>
+#include <FK/VRMLOut.H>
+#include <FK/STLOut.H>
+#include <FK/DXFOut.H>
+#include <FK/MQOOut.H>
+#include <FK/IFSetHandle.H>
 
 #include <algorithm>
 
@@ -94,8 +92,8 @@ using namespace std;
 
 fk_IndexFaceSet::fk_IndexFaceSet(void)
 {
-	setObjectType(FK_INDEXFACESET);
-	setPaletteData(&localPalette);
+	SetObjectType(FK_INDEXFACESET);
+	SetPaletteData(&localPalette);
 
 	posSize = -1;
 	faceSize = -1;
@@ -796,7 +794,7 @@ bool fk_IndexFaceSet::readSMFFile(string argFileName)
 	bool			retFlg;
 
 	smfParser->SetMeshData(this);
-	retFlg = smfParser->readSMFFile(argFileName);
+	retFlg = smfParser->ReadSMFFile(argFileName);
 	delete smfParser;
 	return retFlg;
 }
@@ -808,7 +806,7 @@ bool fk_IndexFaceSet::readSTLFile(string argFileName,
 	bool			retFlg;
 
 	stlParser->SetMeshData(this);
-	retFlg = stlParser->readSTLFile(argFileName, argSolidFlag, argEPS);
+	retFlg = stlParser->ReadSTLFile(argFileName, argSolidFlag, argEPS);
 	delete stlParser;
 	return retFlg;
 }
@@ -819,7 +817,7 @@ bool fk_IndexFaceSet::readHRCFile(string argFileName)
 	bool			retFlg;
 
 	hrcParser->SetMeshData(this);
-	retFlg = hrcParser->readHRCFile(argFileName);
+	retFlg = hrcParser->ReadHRCFile(argFileName);
 	delete hrcParser;
 	return retFlg;
 }
@@ -830,7 +828,7 @@ bool fk_IndexFaceSet::readRDSFile(string argFileName, bool argSolidFlg)
 	bool			retFlg;
 
 	rdsParser->SetMeshData(this);
-	retFlg = rdsParser->readRDSFile(argFileName, argSolidFlg);
+	retFlg = rdsParser->ReadRDSFile(argFileName, argSolidFlg);
 	delete rdsParser;
 	return retFlg;
 }
@@ -841,7 +839,7 @@ bool fk_IndexFaceSet::readDXFFile(string argFileName, bool argSolidFlg)
 	bool			retFlg;
 
 	dxfParser->SetMeshData(this);
-	retFlg = dxfParser->readDXFFile(argFileName, argSolidFlg);
+	retFlg = dxfParser->ReadDXFFile(argFileName, argSolidFlg);
 	delete dxfParser;
 	return retFlg;
 }
@@ -853,7 +851,7 @@ bool fk_IndexFaceSet::readVRMLFile(string argFileName,
 	bool			retFlg;
 
 	vrmlParser->SetMeshData(this);
-	retFlg = vrmlParser->readVRMLFile(argFileName, argMaterialFlag,
+	retFlg = vrmlParser->ReadVRMLFile(argFileName, argMaterialFlag,
 									  argSolidFlag);
 	delete vrmlParser;
 	return retFlg;
@@ -881,9 +879,9 @@ bool fk_IndexFaceSet::readMQOFile(string argFileName,
 	bool			retFlg;
 
 	mqoParser->SetMeshData(this);
-	mqoParser->setContMode(argContFlg);
-	mqoParser->setMaterialMode(argMatFlg);
-	retFlg = mqoParser->readMQOFile(argFileName, argObjName,
+	mqoParser->SetContMode(argContFlg);
+	mqoParser->SetMaterialMode(argMatFlg);
+	retFlg = mqoParser->ReadMQOFile(argFileName, argObjName,
 									argMateID, argSolidFlg);
 	delete mqoParser;
 	return retFlg;
@@ -910,9 +908,9 @@ bool fk_IndexFaceSet::readMQOData(unsigned char *argBuffer,
 	bool			retFlg;
 
 	mqoParser->SetMeshData(this);
-	mqoParser->setContMode(argContFlg);
-	mqoParser->setMaterialMode(argMatFlg);
-	retFlg = mqoParser->readMQOData(argBuffer, argObjName,
+	mqoParser->SetContMode(argContFlg);
+	mqoParser->SetMaterialMode(argMatFlg);
+	retFlg = mqoParser->ReadMQOData(argBuffer, argObjName,
 									argMateID, argSolidFlg);
 	delete mqoParser;
 	return retFlg;
@@ -931,8 +929,8 @@ bool fk_IndexFaceSet::readD3DXFile(string argFileName, string argObjName,
 	bool			retFlg;
 
 	d3dxParser->SetMeshData(this);
-	d3dxParser->setAnimation(anim);
-	retFlg = d3dxParser->readD3DXFile(argFileName, argObjName,
+	d3dxParser->SetAnimation(anim);
+	retFlg = d3dxParser->ReadD3DXFile(argFileName, argObjName,
 									  argTexID, argSolidFlg);
 	setAnimationTime(-1.0);
 	delete d3dxParser;
@@ -945,17 +943,24 @@ bool fk_IndexFaceSet::writeVRMLFile(string argFileName,
 	fk_VRMLOut		*vrmlOut = new fk_VRMLOut(this);
 	bool			retFlg;
 
-	retFlg = vrmlOut->writeVRMLFile(argFileName, argMaterial, triFlag);
+	retFlg = vrmlOut->WriteVRMLFile(argFileName, argMaterial, triFlag);
 	delete vrmlOut;
 	return retFlg;
 }
 
-bool fk_IndexFaceSet::writeVRMLFile(string,
-									vector<double> *,
-									vector<fk_Vector> *,
-									fk_Material *, bool)
+bool fk_IndexFaceSet::writeVRMLFile(string argFileName,
+									vector<double> *argTime,
+									vector<fk_Vector> *argPos,
+									fk_Material *argMaterial,
+									bool argTriFlg)
 {
-	return true;
+	fk_VRMLOut		*vrmlOut = new fk_VRMLOut(this);
+	bool			retFlg;
+
+	retFlg = vrmlOut->WriteVRMLFile(argFileName, argTime, argPos,
+									argMaterial, argTriFlg);
+	delete vrmlOut;
+	return retFlg;
 }
 
 bool fk_IndexFaceSet::writeSTLFile(string argFileName)
@@ -963,7 +968,7 @@ bool fk_IndexFaceSet::writeSTLFile(string argFileName)
 	fk_STLOut		*stlOut = new fk_STLOut(this);
 	bool			retFlg;
 
-	retFlg = stlOut->writeSTLFile(argFileName);
+	retFlg = stlOut->WriteSTLFile(argFileName);
 	delete stlOut;
 	return retFlg;
 }
@@ -973,7 +978,7 @@ bool fk_IndexFaceSet::writeDXFFile(string argFileName, bool argTriFlg)
 	fk_DXFOut		*dxfOut = new fk_DXFOut(this);
 	bool			retFlg;
 
-	retFlg = dxfOut->writeDXFFile(argFileName, argTriFlg);
+	retFlg = dxfOut->WriteDXFFile(argFileName, argTriFlg);
 	delete dxfOut;
 	return retFlg;
 }
@@ -983,7 +988,7 @@ bool fk_IndexFaceSet::writeMQOFile(string argFileName)
 	fk_MQOOut		*mqoOut = new fk_MQOOut(this);
 	bool			retFlg;
 
-	retFlg = mqoOut->writeMQOFile(argFileName);
+	retFlg = mqoOut->WriteMQOFile(argFileName);
 	delete mqoOut;
 	return retFlg;
 }
@@ -1604,7 +1609,7 @@ void fk_IndexFaceSet::putSolid(fk_Solid *argSolid)
 	return;
 }
 
-fk_D3DXAnimation * fk_IndexFaceSet::getAnimation(void)
+fk_D3DXAnimation * fk_IndexFaceSet::GetAnimation(void)
 {
 	return anim;
 }
