@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,7 +69,7 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/MQOParser.h>
+#include <FK/MQOParser.H>
 #include <FK/IFSTexture.h>
 #include <FK/Tree.h>
 
@@ -123,7 +121,7 @@ fk_MQOParser::~fk_MQOParser()
 	return;
 }
 
-bool fk_MQOParser::readMQOFile(const string &argFileName,
+bool fk_MQOParser::ReadMQOFile(const string &argFileName,
 							   const string &argObjName,
 							   int argMateID, bool argSolidFlg)
 {
@@ -137,7 +135,7 @@ bool fk_MQOParser::readMQOFile(const string &argFileName,
 					argMateID, argSolidFlg);
 }
 
-bool fk_MQOParser::readMQOData(unsigned char *argBuffer,
+bool fk_MQOParser::ReadMQOData(unsigned char *argBuffer,
 							   const string &argObjName,
 							   int argMateID, bool argSolidFlg)
 {
@@ -150,7 +148,7 @@ bool fk_MQOParser::readMQOData(unsigned char *argBuffer,
 					argMateID, argSolidFlg);
 }
 
-void fk_MQOParser::setMeshTexture(fk_MeshTexture *argTexture)
+void fk_MQOParser::SetMeshTexture(fk_MeshTexture *argTexture)
 {
 	meshTexture = argTexture;
 	meshData = NULL;
@@ -158,7 +156,7 @@ void fk_MQOParser::setMeshTexture(fk_MeshTexture *argTexture)
 	return;
 }
 
-void fk_MQOParser::setIFSTexture(fk_IFSTexture *argTexture)
+void fk_MQOParser::SetIFSTexture(fk_IFSTexture *argTexture)
 {
 	ifsTexture = argTexture;
 	SetMeshData(argTexture->getIFS());
@@ -742,7 +740,7 @@ void fk_MQOParser::MakeUniqueVertex4Texture(void)
 	}
 
 	if(ifsTexture != NULL) {
-		commonList = ifsTexture->getCommonList();
+		commonList = &(ifsTexture->commonList);
 		commonList->resize(listSet.size());
 		for(i = 0; i < listSet.size(); i++) {
 			for(j = 1; j < listSet[i].size(); j++) {
@@ -784,13 +782,13 @@ void fk_MQOParser::SetIFSTexCoord(void)
 	return;
 }
 
-void fk_MQOParser::setContMode(bool argFlg)
+void fk_MQOParser::SetContMode(bool argFlg)
 {
 	contFlg = argFlg;
 	return;
 }
 
-void fk_MQOParser::setMaterialMode(bool argFlg)
+void fk_MQOParser::SetMaterialMode(bool argFlg)
 {
 	matFlg = argFlg;
 	return;
