@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -194,3 +192,78 @@ bool fk_Math::isCrossLineSegment(const fk_Vector &argA,
 
 	return false;
 }
+
+double fk_Math::calcCosine(fk_Vector pos1, fk_Vector pos2)
+{
+	if(pos1.normalize() == false || pos2.normalize() == false) return 0.0;
+	return(pos1*pos2);
+}
+
+fk_Vector fk_Math::divideVec(const fk_Vector &orgVec,
+							const fk_Vector &vec1,
+							const fk_Vector &vec2,
+							const fk_Vector &vec3)
+{
+	fk_Matrix		mat;
+	fk_Vector		retVec(0.0, 0.0, 0.0);
+
+	mat[0][0] = vec1.x; mat[0][1] = vec2.x; mat[0][2] = vec3.x;
+	mat[1][0] = vec1.y; mat[1][1] = vec2.y; mat[1][2] = vec3.y;
+	mat[2][0] = vec1.z; mat[2][1] = vec2.z; mat[2][2] = vec3.z;
+
+	if(mat.inverse() == false) {
+		return retVec;
+	}
+
+	retVec = mat * orgVec;
+	return retVec;
+}
+
+
+fk_Quaternion & fk_Math::quatInterLinear(const fk_Quaternion &argQ1,
+										 const fk_Quaternion &argQ2,
+										 double argT)
+{
+	static fk_Quaternion q;
+
+	q = (1.0 - argT) * argQ1 + argT * argQ2;
+	q.normalize();
+	return q;
+}
+
+fk_Quaternion & fk_Math::quatInterSphere(const fk_Quaternion &argQ1,
+										 const fk_Quaternion &argQ2,
+										 double argT)
+{
+	static fk_Quaternion	q1, q2, q3;
+	double					theta, sinTheta, prod;
+
+	q1 = argQ1;
+
+	if((argQ1 == argQ2) || (argQ1 == -argQ2)) return q1;
+
+	if((argQ1 ^ argQ2) >= 0.0) {
+		q2 = argQ2;
+	} else {
+		q2 = -argQ2;
+	}
+
+	q1.normalize();
+	q2.normalize();
+
+	prod = q1 ^ q2;
+	if(prod > 1.0) prod = 1.0;
+	if(prod < -1.0) prod = -1.0;
+
+	theta = acos(prod);
+	sinTheta = sin(theta);
+	if(fabs(sinTheta) < FK_VECTOREPS) {
+		q3 = quatInterLinear(argQ1, argQ2, argT);
+	} else {
+		q3 = (sin(theta * (1.0 - argT))/sinTheta) * q1
+			+ (sin(theta*argT)/sinTheta) * q2;
+	}
+
+	return q3;
+}
+
