@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -96,8 +94,8 @@ fk_Model::fk_Model(fk_Shape *argShape)
 	setPickMode(false);
 	setReverseDrawMode(false);
 
-	pointColor = (fk_Color *)NULL;
-	lineColor = (fk_Color *)NULL;
+	pointColor = NULL;
+	lineColor = NULL;
 
 	_modelID = _globalModelID;
 	_globalModelID++;
@@ -129,12 +127,12 @@ void fk_Model::setShape(fk_Shape *argShape)
 {
 	bool	drawModeFlag;
 
-	if(argShape == (fk_Shape *)NULL) {
-		shape = (fk_Shape *)NULL;
+	if(argShape == NULL) {
+		shape = NULL;
 		return;
 	}
 
-	if(shape == (fk_Shape *)NULL) {
+	if(shape == NULL) {
 		drawModeFlag = true;
 	} else if(shape->getObjectType() != argShape->getObjectType()) {
 		drawModeFlag = true;
@@ -186,7 +184,7 @@ void fk_Model::setMaterial(const fk_Material &argMate)
 
 void fk_Model::setPointColor(fk_Color *argColor)
 {
-	if(argColor == (fk_Color *)NULL) {
+	if(argColor == NULL) {
 		return;
 	}
 
@@ -196,7 +194,7 @@ void fk_Model::setPointColor(fk_Color *argColor)
 
 void fk_Model::setPointColor(float argR, float argG, float argB)
 {
-	if(pointColor == (fk_Color *)NULL) {
+	if(pointColor == NULL) {
 		pointColor = new fk_Color();
 	}
 
@@ -206,7 +204,7 @@ void fk_Model::setPointColor(float argR, float argG, float argB)
 
 void fk_Model::setLineColor(fk_Color *argColor)
 {
-	if(argColor == (fk_Color *)NULL) {
+	if(argColor == NULL) {
 		return;
 	}
 
@@ -216,7 +214,7 @@ void fk_Model::setLineColor(fk_Color *argColor)
 
 void fk_Model::setLineColor(float argR, float argG, float argB)
 {
-	if(lineColor == (fk_Color *)NULL) {
+	if(lineColor == NULL) {
 		lineColor = new fk_Color();
 	}
 
@@ -236,7 +234,7 @@ fk_Material * fk_Model::getMaterial(void)
 
 fk_Material * fk_Model::getInhMaterial(void)
 {
-	if(parent != (fk_Model *)NULL) {
+	if(parent != NULL) {
 		if(materialFlag == false) {
 			return parent->getInhMaterial();
 		} else {
@@ -253,8 +251,8 @@ fk_Color * fk_Model::getPointColor(void)
 
 fk_Color * fk_Model::getInhPointColor(void)
 {
-	if(parent != (fk_Model *)NULL) {
-		if(pointColor == (fk_Color *)NULL) {
+	if(parent != NULL) {
+		if(pointColor == NULL) {
 			return parent->getInhPointColor();
 		} else {
 			return pointColor;
@@ -270,8 +268,8 @@ fk_Color * fk_Model::getLineColor(void)
 
 fk_Color * fk_Model::getInhLineColor(void)
 {
-	if(parent != (fk_Model *)NULL) {
-		if(lineColor == (fk_Color *)NULL) {
+	if(parent != NULL) {
+		if(lineColor == NULL) {
 			return parent->getInhLineColor();
 		} else {
 			return lineColor;
@@ -289,14 +287,14 @@ void fk_Model::deleteMaterial(void)
 void fk_Model::deletePointColor(void)
 {
 	delete pointColor;
-	pointColor = (fk_Color *)NULL;
+	pointColor = NULL;
 	return;
 }
 
 void fk_Model::deleteLineColor(void)
 {
 	delete lineColor;
-	lineColor = (fk_Color *)NULL;
+	lineColor = NULL;
 	return;
 }
 
@@ -324,27 +322,27 @@ fk_MaterialMode fk_Model::getMaterialMode(void) const
 
 fk_Matrix fk_Model::getInhMatrix(void) const
 {
-	if(parent == (fk_Model *)NULL) return getMatrix();
+	if(parent == NULL) return getMatrix();
 	return (parent->getInhMatrix() * getMatrix());
 }
 
 fk_Matrix fk_Model::getInhInvMatrix(void) const
 {
-	if(parent == (fk_Model *)NULL) return getInvMatrix();
+	if(parent == NULL) return getInvMatrix();
 	return (getInvMatrix() * parent->getInhInvMatrix());
 }
 
-fk_UnitMatrix fk_Model::getInhBaseMatrix(void) const
+fk_OrthoMatrix fk_Model::getInhBaseMatrix(void) const
 {
-	if(parent == (fk_Model *)NULL) return UnitaryMatrix;
-	return (parent->getInhBaseMatrix() * UnitaryMatrix);
+	if(parent == NULL) return OrthoMatrix;
+	return (parent->getInhBaseMatrix() * OrthoMatrix);
 }
 
-fk_UnitMatrix fk_Model::getInhInvBaseMatrix(void) const
+fk_OrthoMatrix fk_Model::getInhInvBaseMatrix(void) const
 {
-	fk_UnitMatrix	RetMat = UnitaryMatrix;
+	fk_OrthoMatrix	RetMat = OrthoMatrix;
 	RetMat.inverse();
-	if(parent == (fk_Model *)NULL) return RetMat;
+	if(parent == NULL) return RetMat;
 	return (parent->getInhInvBaseMatrix() * RetMat);
 }
 
@@ -352,7 +350,7 @@ fk_Vector fk_Model::getInhPosition(void) const
 {
 	fk_Vector retVec;
 
-	if(parent == (fk_Model *)NULL) {
+	if(parent == NULL) {
 		retVec = Position;
 	} else {
 		retVec = parent->getInhMatrix() * Position;
@@ -364,28 +362,33 @@ fk_Vector fk_Model::getInhVec(void) const
 {
 	fk_HVector	hvec(Vec);
 
-	if(parent == (fk_Model *)NULL) return Vec;
+	if(parent == NULL) return Vec;
 
 	hvec.isvec();
 	return (parent->getInhMatrix() * hvec);
 }
 	
-fk_Vector fk_Model::getInhUpVec(void) const
+fk_Vector fk_Model::getInhUpvec(void) const
 {
 	fk_HVector	hvec(UpVec);
 
-	if(parent == (fk_Model *)NULL) return UpVec;
+	if(parent == NULL) return UpVec;
 	
 	hvec.isvec();
 	return (parent->getInhMatrix() * hvec);
 }
 
+fk_Vector fk_Model::getInhUpVec(void) const
+{
+	return getInhUpvec();
+}
+
 fk_Angle fk_Model::getInhAngle(void) const
 {
 	fk_Angle		retAngle;
 	fk_Vector		vec, upvec;
 
-	if(parent == (fk_Model *)NULL) return Angle;
+	if(parent == NULL) return Angle;
 	vec = getInhVec();
 	upvec = getInhUpVec();
 	VectorToAngle(&retAngle, &vec, &upvec);
@@ -535,7 +538,7 @@ bool fk_Model::isInterference(fk_Model *argModel)
 {
 	fk_SphereBoundary		sb1, sb2;
 
-	if(argModel == (fk_Model *)NULL) return false;
+	if(argModel == NULL) return false;
 	sb1.setRadius(sbRadius);
 	sb2.setRadius(argModel->sbRadius);
 	sb1.setCurPos(getInhPosition());
@@ -548,7 +551,7 @@ bool fk_Model::isCollision(fk_Model *argModel)
 {
 	fk_SphereBoundary		sb1, sb2;
 
-	if(argModel == (fk_Model *)NULL) return false;
+	if(argModel == NULL) return false;
 	if(snapFlag == false || argModel->snapFlag == false) return false;
 	sb1.setRadius(sbRadius);
 	sb2.setRadius(argModel->sbRadius);
@@ -564,7 +567,7 @@ double fk_Model::getCollisionTime(fk_Model *argModel)
 {
 	fk_SphereBoundary		sb1, sb2;
 
-	if(argModel == (fk_Model *)NULL) return 0.0;
+	if(argModel == NULL) return 0.0;
 	if(snapFlag == false || argModel->snapFlag == false) return 0.0;
 	sb1.setRadius(sbRadius);
 	sb2.setRadius(argModel->sbRadius);
