@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,13 +70,12 @@
  *
  ****************************************************************************/
 #include <FK/Modify.h>
-#include <FK/IFSetHandle.h>
+#include <FK/IFSetHandle.H>
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -130,7 +127,7 @@ fk_Loop * fk_Modify::removeVertexInLoop(fk_Vertex *argVx)
 	return retL;
 }
 
-bool fk_Modify::contractEdge(fk_Edge *argEd)
+bool fk_Modify::contractEdge(fk_Edge *argEd, bool rightFlg)
 {
 	fk_Vector		newPos;
 	fk_Vertex		*rV, *lV;
@@ -146,10 +143,10 @@ bool fk_Modify::contractEdge(fk_Edge *argEd)
 
 	newPos = (rV->getPosition() + lV->getPosition())/2.0;
 
-	return contractEdge(argEd, newPos);
+	return contractEdge(argEd, newPos, rightFlg);
 }
 
-bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos)
+bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos, bool rightFlg)
 {
 	fk_Vertex				*remainV, *deleteV;
 	fk_Vertex				*NeighborV[2];
@@ -178,16 +175,29 @@ bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos)
 	// 稜線が削除できる状態にない 
 	if(checkContract(argEd) == false) return false;
 
-	// remainV に残す頂点を, deleteV に削除する頂点を代入 
-	remainV = getRightVOnE(argEd);
-	deleteV = getLeftVOnE(argEd);
+	if(rightFlg == true) {
+		// remainV に残す頂点を, deleteV に削除する頂点を代入 
+		remainV = getRightVOnE(argEd);
+		deleteV = getLeftVOnE(argEd);
 
-	// 頂点の移動先を計算 
-	newArgFirstH = getLeftHOnE(argEd)->getNextHalf();
+		// 頂点の移動先を計算 
+		newArgFirstH = getLeftHOnE(argEd)->getNextHalf();
 
-	// argEd の対になる頂点の取得 
-	NeighborV[0] = newArgFirstH->getNextHalf()->getVertex();
-	NeighborV[1] = getRightHOnE(argEd)->getPrevHalf()->getVertex();
+		// argEd の対になる頂点の取得 
+		NeighborV[0] = newArgFirstH->getNextHalf()->getVertex();
+		NeighborV[1] = getRightHOnE(argEd)->getPrevHalf()->getVertex();
+	} else {
+		// remainV に残す頂点を, deleteV に削除する頂点を代入 
+		remainV = getLeftVOnE(argEd);
+		deleteV = getRightVOnE(argEd);
+
+		// 頂点の移動先を計算 
+		newArgFirstH = getRightHOnE(argEd)->getNextHalf();
+
+		// argEd の対になる頂点の取得 
+		NeighborV[0] = newArgFirstH->getNextHalf()->getVertex();
+		NeighborV[1] = getLeftHOnE(argEd)->getPrevHalf()->getVertex();
+	}
 
 	// argEd を削除 
 	if(uniteLoop(argEd) == false) return false;
@@ -313,7 +323,7 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 	if(checkDB() == false) return retL;
 
 	if(argClearFlg == true) {
-		allClear();
+		AllClear_();
 	}
 
 	for(i = 0; i < argVec->size(); i++) {
@@ -323,7 +333,7 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 
 	if((prevE = makeEdge(VertexArray[1], VertexArray[0])) == (fk_Edge *)NULL) {
 		fk_PutError("fk_Modify", "makePolygon", 1, "Make Edge Error.");
-		allClear();
+		AllClear_();
 		return retL;
 	}
 
@@ -341,7 +351,7 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 		if((prevE = makeEdge(VertexArray[i-1], VertexArray[i],
 							 prevH, nextH)) == (fk_Edge *)NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 2, "Make Edge Error.");
-			allClear();
+			AllClear_();
 			return retL;
 		}
 	}
@@ -356,12 +366,12 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 		if(makeEdge(VertexArray.back(), VertexArray[0],
 					prevH, nextH, prevH2, nextH2) == (fk_Edge *)NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 3, "Make Edge Error.");
-			allClear();
+			AllClear_();
 			return retL;
 		}
 		if((retL = makeLoop(prevH)) == (fk_Loop *)NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 4, "Make Loop Error.");
-			allClear();
+			AllClear_();
 			return retL;
 		}
 	}
@@ -420,7 +430,7 @@ void fk_Modify::pushPolygonVertex(fk_Vector argVec, bool argOpenFlg)
 			}
 
 			VecArray.push_back(argVec);
-			allClear();
+			AllClear_();
 			makePolygon(&VecArray, false);
 		}
 
@@ -453,7 +463,7 @@ void fk_Modify::makePoint(vector<fk_Vector> *argVec)
 
 	if(argVec == (vector<fk_Vector> *)NULL) return;
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	for(i = 0; i < argVec->size(); i++) {
 		makeVertex((*argVec)[i]);
@@ -467,7 +477,7 @@ void fk_Modify::makePoint(int argNum, fk_Vector *argVec)
 	int		i;
 
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	for(i = 0; i < argNum; i++) {
 		makeVertex(argVec[i]);
@@ -488,7 +498,7 @@ void fk_Modify::makeLines(vector<fk_Vector> *argVec)
 
 	if(argVec == (vector<fk_Vector> *)NULL) return;
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	for(i = 0; i < argVec->size()/2; i++) {
 		v1 = makeVertex((*argVec)[2*i]);
@@ -506,7 +516,7 @@ void fk_Modify::makeLines(int argNum, fk_Vector *argVec)
 
 	if(argVec == (fk_Vector *)NULL) return;
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	for(i = 0; i < argNum; i++) {
 		v1 = makeVertex(argVec[2*i]);
@@ -592,7 +602,7 @@ void fk_Modify::makeBlock(double argX, double argY, double argZ)
 
 	if(checkDB() == false) return;
 
-	allClear();
+	AllClear_();
 	IFSet.SetDataBase(GetDB());
 
 	VecArray.clear();
@@ -753,7 +763,7 @@ void fk_Modify::makeCircle(int argDiv, double argRadius)
 	double					theta;
 
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	IFSet.SetDataBase(GetDB());
 
@@ -858,7 +868,7 @@ void fk_Modify::makeSphere(int argDiv, double argRadius)
 
 	if(checkDB() == false) return;
 
-	allClear();
+	AllClear_();
 	IFSet.SetDataBase(GetDB());
 
 	VecArray.resize(argDiv*4 * (argDiv*2 - 1) + 2);
@@ -1001,7 +1011,7 @@ void fk_Modify::makePrism(int argDiv, double argTop, double argBottom,
 	double					theta;
 
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	IFSet.SetDataBase(GetDB());
 
@@ -1156,7 +1166,7 @@ void fk_Modify::makeCone(int argDiv, double argRadius, double argHeight)
 	double					theta;
 
 	if(checkDB() == false) return;
-	allClear();
+	AllClear_();
 
 	IFSet.SetDataBase(GetDB());
 	
