@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,14 +70,14 @@
  *
  ****************************************************************************/
 #include <FK/Palette.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
 static fk_Material dummyMat;
 
 fk_Palette::fk_Palette(void)
-	: fk_BaseObject(FK_MATERIALADMIN)
+	: fk_BaseObject(FK_PALETTE)
 {
 	clearMaterial();
 	return;
@@ -98,11 +96,13 @@ void fk_Palette::clearMaterial(void)
 	return;
 }
 
+/*
 void fk_Palette::setObjMaterial(fk_Material *argMaterial)
 {
 	thisMaterial = *argMaterial;
 	thisColorID = FK_UNDEFINED;
 }
+*/
 
 void fk_Palette::setObjMaterialID(int argID)
 {
@@ -138,11 +138,12 @@ void fk_Palette::setPalette(fk_Material *argMaterial,
 	return;
 }
 
+/*
 fk_Material * fk_Palette::getObjMaterial(void)
 {
-
 	return &thisMaterial;
 }
+*/
 
 int fk_Palette::getObjMaterialID(void)
 {
@@ -180,7 +181,7 @@ void fk_Palette::Print(int argTabSize, string argTag)
 	}
 
 	fk_PutError(tab + fk_StrPrintf("\tthisColorID = %d;", thisColorID));
-	thisMaterial.Print(argTabSize + 1, "THISMAT");
+	//thisMaterial.Print(argTabSize + 1, "THISMAT");
 	for(i = 0; i < (int)paletteStack.size(); i++) {
 		paletteStack[i].Print(argTabSize + 1, fk_StrPrintf("PAL%d", i));
 	}
