@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,7 +69,7 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/ParserBase.h>
+#include <FK/ParserBase.H>
 #include <algorithm>
 
 using namespace std;
@@ -203,7 +201,7 @@ bool fk_ParserBase::ReadLine(FILE *argFP, string *argOutStr)
 	return true;
 }
 
-void fk_ParserBase::pushOneLineCommentSep(const string argSep)
+void fk_ParserBase::PushOneLineCommentSep(const string argSep)
 {
 	if(find(commentStack.begin(),
 			commentStack.end(), argSep) == commentStack.end()) {
@@ -315,7 +313,7 @@ bool fk_ParserBase::IsNumeric(const string &argStr)
 	return true;
 }
 
-void fk_ParserBase::bSwap(int *argP)
+void fk_ParserBase::BSwap(int *argP)
 {
 	int		tmp = *argP;
 	char	*p = (char *)argP;
@@ -328,7 +326,7 @@ void fk_ParserBase::bSwap(int *argP)
 	return;
 }
 
-void fk_ParserBase::bSwap(float *argP)
+void fk_ParserBase::BSwap(float *argP)
 {
 	float	tmp = *argP;
 	char	*p = (char *)argP;
@@ -341,7 +339,7 @@ void fk_ParserBase::bSwap(float *argP)
 	return;
 }
 
-void fk_ParserBase::bSwap(double *argP)
+void fk_ParserBase::BSwap(double *argP)
 {
 	double	tmp = *argP;
 	char	*p = (char *)argP;
@@ -358,48 +356,48 @@ void fk_ParserBase::bSwap(double *argP)
 	return;
 }
 
-bool fk_ParserBase::bRead(int *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BRead(int *argP, size_t argSize, FILE *argFP)
 {
 	
 	if(fread(argP, sizeof(int), argSize, argFP) != argSize) return false;
 	
 #ifdef __BIG_ENDIAN__
-	for(int i = 0; i < int(argSize); i++) bSwap(&argP[i]);
+	for(int i = 0; i < int(argSize); i++) BSwap(&argP[i]);
 #endif
 
 	return true;
 }
 
-bool fk_ParserBase::bRead(float *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BRead(float *argP, size_t argSize, FILE *argFP)
 {
 	
 	if(fread(argP, sizeof(float), argSize, argFP) != argSize) return false;
 	
 #ifdef __BIG_ENDIAN__
-	for(int i = 0; i < int(argSize); i++) bSwap(&argP[i]);
+	for(int i = 0; i < int(argSize); i++) BSwap(&argP[i]);
 #endif
 
 	return true;
 }
 
-bool fk_ParserBase::bRead(double *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BRead(double *argP, size_t argSize, FILE *argFP)
 {
 	
 	if(fread(argP, sizeof(double), argSize, argFP) != argSize) return false;
 	
 #ifdef __BIG_ENDIAN__
-	for(int i = 0; i < int(argSize); i++) bSwap(&argP[i]);
+	for(int i = 0; i < int(argSize); i++) BSwap(&argP[i]);
 #endif
 
 	return true;
 }
 
-bool fk_ParserBase::bWrite(int *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BWrite(int *argP, size_t argSize, FILE *argFP)
 {
 
 #ifdef __BIG_ENDIAN__
 	for(int i = 0; i < int(argSize); i++) {
-		bSwap(&argP[i]);
+		BSwap(&argP[i]);
 	}
 #endif
 	
@@ -407,12 +405,12 @@ bool fk_ParserBase::bWrite(int *argP, size_t argSize, FILE *argFP)
 	return true;
 }
 
-bool fk_ParserBase::bWrite(float *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BWrite(float *argP, size_t argSize, FILE *argFP)
 {
 
 #ifdef __BIG_ENDIAN__
 	for(int i = 0; i < int(argSize); i++) {
-		bSwap(&argP[i]);
+		BSwap(&argP[i]);
 	}
 #endif
 	
@@ -420,12 +418,12 @@ bool fk_ParserBase::bWrite(float *argP, size_t argSize, FILE *argFP)
 	return true;
 }
 
-bool fk_ParserBase::bWrite(double *argP, size_t argSize, FILE *argFP)
+bool fk_ParserBase::BWrite(double *argP, size_t argSize, FILE *argFP)
 {
 
 #ifdef __BIG_ENDIAN__
 	for(int i = 0; i < int(argSize); i++) {
-		bSwap(&argP[i]);
+		BSwap(&argP[i]);
 	}
 #endif
 	
