@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,8 +73,8 @@
 #include "PointDraw_D3D.cxx"
 #else
 
-#include <FK/PointDraw.h>
-#include <FK/OpenGL.h>
+#include <FK/PointDraw.H>
+#include <FK/OpenGL.H>
 #include <FK/Model.h>
 #include <FK/Point.h>
 #include <FK/Solid.h>
@@ -87,7 +85,7 @@ using namespace std;
 
 fk_PointDraw::fk_PointDraw(void)
 {
-	setArrayState(false);
+	SetArrayState(false);
 }
 
 fk_PointDraw::~fk_PointDraw()
@@ -95,13 +93,13 @@ fk_PointDraw::~fk_PointDraw()
 	return;
 }
 
-void fk_PointDraw::setArrayState(bool argState)
+void fk_PointDraw::SetArrayState(bool argState)
 {
 	arrayState = argState;
 	return;
 }
 
-void fk_PointDraw::drawShapePoint(fk_Model *argObj, bool argPickFlag)
+void fk_PointDraw::DrawShapePoint(fk_Model *argObj, bool argPickFlag)
 {
 	fk_MaterialMode	shapeMateMode;
 	fk_MaterialMode	modelMateMode;
