@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -78,7 +76,7 @@ using namespace std;
 fk_Polygon::fk_Polygon(vector<fk_Vector> *argVertexSet,
 					   fk_ObjectType argObjType)
 {
-	setObjectType(argObjType);
+	SetObjectType(argObjType);
 
 	allClear();
 
@@ -131,7 +129,7 @@ void fk_Polygon::setVertex(vector<fk_Vector> *argPosArray)
 
 fk_Polyline::fk_Polyline(vector<fk_Vector> *argVertexSet)
 {
-	setObjectType(FK_POLYLINE);
+	SetObjectType(FK_POLYLINE);
 	makePolygon(argVertexSet, true);
 	return;
 }
