@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,21 +70,21 @@
  *
  ****************************************************************************/
 #include <FK/Solid.h>
-#include <FK/DataBase.h>
-#include <FK/FileInput.h>
-#include <FK/FileOutput.h>
-#include <FK/SMFParser.h>
-#include <FK/STLParser.h>
-#include <FK/HRCParser.h>
-#include <FK/RDSParser.h>
-#include <FK/DXFParser.h>
-#include <FK/VRMLParser.h>
-#include <FK/MQOParser.h>
-#include <FK/D3DXParser.h>
-#include <FK/VRMLOut.h>
-#include <FK/STLOut.h>
-#include <FK/DXFOut.h>
-#include <FK/MQOOut.h>
+#include <FK/DataBase.H>
+#include <FK/FileInput.H>
+#include <FK/FileOutput.H>
+#include <FK/SMFParser.H>
+#include <FK/STLParser.H>
+#include <FK/HRCParser.H>
+#include <FK/RDSParser.H>
+#include <FK/DXFParser.H>
+#include <FK/VRMLParser.H>
+#include <FK/MQOParser.H>
+#include <FK/D3DXParser.H>
+#include <FK/VRMLOut.H>
+#include <FK/STLOut.H>
+#include <FK/DXFOut.H>
+#include <FK/MQOOut.H>
 
 using namespace std;
 
@@ -94,9 +92,9 @@ fk_Solid::fk_Solid(void)
 {
 	SolidDB = new fk_DataBase;
 
-	setObjectType(FK_SOLID);
+	SetObjectType(FK_SOLID);
 	SetDataBase(SolidDB);
-	setPaletteData(&localPal);
+	SetPaletteData(&localPal);
 	return;
 }
 
@@ -148,7 +146,7 @@ bool fk_Solid::readSMFFile(string argFileName)
 
 	smfParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = smfParser->readSMFFile(argFileName);
+	retFlg = smfParser->ReadSMFFile(argFileName);
 	delete smfParser;
 	return retFlg;
 }
@@ -161,7 +159,7 @@ bool fk_Solid::readSTLFile(string argFileName,
 
 	stlParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = stlParser->readSTLFile(argFileName, argSolidFlag, argEPS);
+	retFlg = stlParser->ReadSTLFile(argFileName, argSolidFlag, argEPS);
 	delete stlParser;
 	return retFlg;
 }
@@ -173,7 +171,7 @@ bool fk_Solid::readHRCFile(string argFileName)
 
 	hrcParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = hrcParser->readHRCFile(argFileName);
+	retFlg = hrcParser->ReadHRCFile(argFileName);
 	delete hrcParser;
 	return retFlg;
 }
@@ -185,7 +183,7 @@ bool fk_Solid::readRDSFile(string argFileName, bool argSolidFlg)
 
 	rdsParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = rdsParser->readRDSFile(argFileName, argSolidFlg);
+	retFlg = rdsParser->ReadRDSFile(argFileName, argSolidFlg);
 	delete rdsParser;
 	return retFlg;
 }
@@ -197,7 +195,7 @@ bool fk_Solid::readDXFFile(string argFileName, bool argSolidFlg)
 
 	dxfParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = dxfParser->readDXFFile(argFileName, argSolidFlg);
+	retFlg = dxfParser->ReadDXFFile(argFileName, argSolidFlg);
 	delete dxfParser;
 	return retFlg;
 }
@@ -221,9 +219,9 @@ bool fk_Solid::readMQOFile(string argFileName, string argObjName,
 
 	mqoParser->SetMeshData(this);
 	AllCacheClear();
-	mqoParser->setContMode(argContFlg);
-	mqoParser->setMaterialMode(argMatFlg);
-	retFlg = mqoParser->readMQOFile(argFileName, argObjName,
+	mqoParser->SetContMode(argContFlg);
+	mqoParser->SetMaterialMode(argMatFlg);
+	retFlg = mqoParser->ReadMQOFile(argFileName, argObjName,
 									argMateID, argSolidFlg);
 	delete mqoParser;
 	return retFlg;
@@ -243,7 +241,7 @@ bool fk_Solid::readD3DXFile(string argFileName, string argObjName,
 
 	d3dxParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = d3dxParser->readD3DXFile(argFileName, argObjName,
+	retFlg = d3dxParser->ReadD3DXFile(argFileName, argObjName,
 									  argTexID, argSolidFlg);
 	delete d3dxParser;
 	return retFlg;
@@ -257,7 +255,7 @@ bool fk_Solid::readVRMLFile(string argFileName,
 
 	vrmlParser->SetMeshData(this);
 	AllCacheClear();
-	retFlg = vrmlParser->readVRMLFile(argFileName, argMaterialFlag,
+	retFlg = vrmlParser->ReadVRMLFile(argFileName, argMaterialFlag,
 									  argSolidFlag);
 	delete vrmlParser;
 	return retFlg;
@@ -269,7 +267,7 @@ bool fk_Solid::writeVRMLFile(string argFileName, fk_Material *argMaterial,
 	fk_VRMLOut		*vrmlOut = new fk_VRMLOut(this);
 	bool			retFlg;
 
-	retFlg = vrmlOut->writeVRMLFile(argFileName, argMaterial, triFlag);
+	retFlg = vrmlOut->WriteVRMLFile(argFileName, argMaterial, triFlag);
 	delete vrmlOut;
 	return retFlg;
 }
@@ -282,7 +280,7 @@ bool fk_Solid::writeVRMLFile(string argFileName,
 	fk_VRMLOut		*vrmlOut = new fk_VRMLOut(this);
 	bool			retFlg;
 
-	retFlg = vrmlOut->writeVRMLFile(argFileName, argTime, argPos,
+	retFlg = vrmlOut->WriteVRMLFile(argFileName, argTime, argPos,
 									argMaterial, triFlag);
 	delete vrmlOut;
 	return retFlg;
@@ -293,7 +291,7 @@ bool fk_Solid::writeSTLFile(string argFileName)
 	fk_STLOut		*stlOut = new fk_STLOut(this);
 	bool			retFlg;
 
-	retFlg = stlOut->writeSTLFile(argFileName);
+	retFlg = stlOut->WriteSTLFile(argFileName);
 	delete stlOut;
 	return retFlg;
 }
@@ -303,7 +301,7 @@ bool fk_Solid::writeDXFFile(string argFileName, bool argTriFlg)
 	fk_DXFOut		*dxfOut = new fk_DXFOut(this);
 	bool			retFlg;
 
-	retFlg = dxfOut->writeDXFFile(argFileName, argTriFlg);
+	retFlg = dxfOut->WriteDXFFile(argFileName, argTriFlg);
 	delete dxfOut;
 	return retFlg;
 }
@@ -313,7 +311,7 @@ bool fk_Solid::writeMQOFile(string argFileName)
 	fk_MQOOut		*mqoOut = new fk_MQOOut(this);
 	bool			retFlg;
 
-	retFlg = mqoOut->writeMQOFile(argFileName);
+	retFlg = mqoOut->WriteMQOFile(argFileName);
 	delete mqoOut;
 	return retFlg;
 }
