@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -74,7 +72,7 @@
 #include <FK/SolidBase.h>
 #include <FK/IndexFace.h>
 #include <FK/Shape.h>
-#include <FK/IFSetHandle.h>
+#include <FK/IFSetHandle.H>
 #include <FK/Loop.h>
 #include <FK/Material.h>
 
@@ -92,7 +90,7 @@ fk_SolidBase::~fk_SolidBase()
 
 void fk_SolidBase::Init(void)
 {
-	allClear();
+	AllClear_();
 	return;
 }
 
@@ -121,11 +119,6 @@ bool fk_SolidBase::MakeMesh(vector<fk_Vector> *vData,
 	if(MaterialIDSet == (vector<int> *)NULL) return true;
 	if(getPaletteSize() == 0) return true;
 
-	if(getPaletteSize() == 1) {
-		setObjMaterial((*getMaterialVector())[0]);
-		return true;
-	}
-
 	for(i = 0; i < MaterialIDSet->size(); i++) {
 		Loop = getLData(i+1);
 		if(Loop != (fk_Loop *)NULL) {
@@ -179,16 +172,3 @@ void fk_SolidBase::makeIFSet(int argTNum, int argPNum, int *argIF,
 	MakeMesh(&posSet, &IFSet);
 	return;
 }
-
-
-bool fk_SolidBase::refineTopology(void)
-{
-	bool				retStatus;
-
-	fk_IFSetHandle		*ifHandle = new fk_IFSetHandle(GetDB());
-
-	retStatus = ifHandle->refineTopology();
-	delete ifHandle;
-
-	return retStatus;
-}
