@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/TextImage.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <ft2build.h>
 
 #include <map>
@@ -408,7 +406,7 @@ static bool				cacheMode = false;
 
 fk_TextImage::fk_TextImage(void)
 {
-	setObjectType(FK_TEXTIMAGE);
+	SetObjectType(FK_TEXTIMAGE);
 	setDPI(48);
 	setPTSize(48);
 	setCharSkip(0);
