@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Texture.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -112,7 +110,7 @@ void fk_TexCoord::set(double argX, double argY)
 fk_Texture::fk_Texture(fk_Image *argImage)
 	: fk_Shape(FK_TEXTURE)
 {
-	setPaletteData(&localPal);
+	SetPaletteData(&localPal);
 	image = (fk_Image *)NULL;
 	BaseInit();
 	setImage(argImage);
@@ -163,6 +161,12 @@ bool fk_Texture::readPNGData(fk_ImType *argBuffer)
 	return image->readPNGData(argBuffer);
 }
 
+bool fk_Texture::readJPG(string argFileName)
+{
+	setImage(&localImage);
+	return image->readJPG(argFileName);
+}
+
 const fk_ImType * fk_Texture::getImageBuf(void)
 {
 	if(image != (fk_Image *)NULL) {
@@ -281,7 +285,7 @@ void fk_Texture::fillColor(int argR, int argG, int argB, int argA)
 fk_RectTexture::fk_RectTexture(fk_Image *argImage)
 	: fk_Texture(argImage)
 {
-	setObjectType(FK_RECTTEXTURE);
+	SetObjectType(FK_RECTTEXTURE);
 	texSize.set(2.0, 2.0);
 	setRepeatMode(false);
 	repeatParam.set(1.0, 1.0);
@@ -390,7 +394,7 @@ fk_TexCoord fk_RectTexture::getTextureCoord(int argID)
 fk_TriTexture::fk_TriTexture(fk_Image *argImage)
 	: fk_Texture(argImage)
 {
-	setObjectType(FK_TRITEXTURE);
+	SetObjectType(FK_TRITEXTURE);
 
 	return;
 }
