@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Tree.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <algorithm>
 
 using namespace std;
@@ -205,7 +203,7 @@ void fk_TreeData::_clearChild(fk_TreeData *argChild)
 	return;
 }
 
-void fk_TreeData::print(void)
+void fk_TreeData::Print(void)
 {
 	list_ite	ite;
 	string		str, tmpLine;
@@ -218,7 +216,7 @@ void fk_TreeData::print(void)
 	fk_PutError(str);
 
 	for(ite = children.begin(); ite != children.end(); ite++) {
-		(*ite)->print();
+		(*ite)->Print();
 	}
 	return;
 }
@@ -275,25 +273,25 @@ fk_TreeData * fk_Tree::makeNewData(fk_Tree *argTree, string argName,
 
 void fk_Tree::_makeRoot(const string argName)
 {
-	root = makeNewData(this, argName, NULL);
-	treeData.push_back(root);
+	_root = makeNewData(this, argName, NULL);
+	_treeData.push_back(_root);
 	return;
 }
 
 
 fk_TreeData * fk_Tree::getRoot(void)
 {
-	return root;
+	return _root;
 }
 
 void fk_Tree::_clear(void)
 {
 	list_ite		ite;
 
-	for(ite = treeData.begin(); ite != treeData.end(); ite++) {
+	for(ite = _treeData.begin(); ite != _treeData.end(); ite++) {
 		delete *ite;
 	}
-	treeData.clear();
+	_treeData.clear();
 	return;
 }
 
@@ -301,10 +299,10 @@ void fk_Tree::_clearData(fk_TreeData *argData)
 {
 	list_ite		ite;
 
-	ite = find(treeData.begin(), treeData.end(), argData);
-	if(ite != treeData.end()) {
+	ite = find(_treeData.begin(), _treeData.end(), argData);
+	if(ite != _treeData.end()) {
 		delete (*ite);
-		treeData.erase(ite);
+		_treeData.erase(ite);
 	}
 	return;
 }
@@ -321,7 +319,7 @@ bool fk_Tree::isArive(fk_TreeData *argData)
 	if(argData == NULL) return false;
 	if(argData->base != this) return false;
 
-	if(find(treeData.begin(), treeData.end(), argData) != treeData.end()) {
+	if(find(_treeData.begin(), _treeData.end(), argData) != _treeData.end()) {
 		return true;
 	}
 	return false;
@@ -334,7 +332,7 @@ fk_TreeData * fk_Tree::addNewChild(fk_TreeData *argData, const string argName)
 	if(isArive(argData) == false) return NULL;
 
 	newData = makeNewData(this, argName, argData);
-	treeData.push_back(newData);
+	_treeData.push_back(newData);
 	argData->_addChild(newData);
 
 	return newData;
@@ -345,7 +343,7 @@ bool fk_Tree::deleteBranch(fk_TreeData *argData)
 	fk_TreeData		*parent;
 
 	if(isArive(argData) == false) return false;
-	if(argData == root) return false;
+	if(argData == _root) return false;
 
 	parent = argData->parent;
 
@@ -519,7 +517,7 @@ fk_TreeData * fk_Tree::findData(const string argName)
 	list_ite		ite;
 	fk_TreeData		*cur;
 
-	for(ite = treeData.begin(); ite != treeData.end(); ite++) {
+	for(ite = _treeData.begin(); ite != _treeData.end(); ite++) {
 		cur = *ite;
 		if(cur->name == argName) return cur;
 	}
@@ -531,17 +529,17 @@ fk_TreeData * fk_Tree::foreachData(fk_TreeData *argData)
 	list_ite		ite;
 
 	if(argData == NULL) {
-		return treeData.front();
+		return _treeData.front();
 	}
-	ite = find(treeData.begin(), treeData.end(), argData);
-	if(ite == treeData.end()) return NULL;
+	ite = find(_treeData.begin(), _treeData.end(), argData);
+	if(ite == _treeData.end()) return NULL;
 	ite++;
-	if(ite == treeData.end()) return NULL;
+	if(ite == _treeData.end()) return NULL;
 	return (*ite);
 }
 
-void fk_Tree::print(void)
+void fk_Tree::Print(void)
 {
-	root->print();
+	_root->Print();
 	return;
 }
