@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/UniCode.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <imdkcv/imdkcvlib.h>
 
 using namespace std;
@@ -82,7 +80,7 @@ static fk_StrConverter		strConverter;
 fk_UniChar::fk_UniChar(int argCode)
 	: fk_BaseObject(FK_UNICHAR)
 {
-	SetCode(argCode);
+	setCode(argCode);
 	return;
 }
 
@@ -100,7 +98,7 @@ fk_UniChar & fk_UniChar::operator =(const fk_UniChar &argUC)
 	return *this;
 }
 
-bool fk_UniChar::ReadFile(FILE *argFP)
+bool fk_UniChar::readFile(FILE *argFP)
 {
 	unsigned char	buffer[3];
 
@@ -110,29 +108,29 @@ bool fk_UniChar::ReadFile(FILE *argFP)
 		return false;
 	}
 
-	SetBuffer(buffer[0], buffer[1]);
+	setBuffer(buffer[0], buffer[1]);
 
 	return true;
 }
 
-void fk_UniChar::SetBuffer(unsigned char argC1, unsigned char argC2)
+void fk_UniChar::setBuffer(unsigned char argC1, unsigned char argC2)
 {
 	code = int(argC1) + int(argC2)*256;
 	return;
 }
 
-void fk_UniChar::SetCode(int argCode)
+void fk_UniChar::setCode(int argCode)
 {
 	code = argCode;
 	return;
 }
 
-int fk_UniChar::GetCode(void)
+int fk_UniChar::getCode(void)
 {
 	return code;
 }
 
-bool fk_UniChar::IsAscii(void)
+bool fk_UniChar::isAscii(void)
 {
 	if(code < 128) {
 		return true;
@@ -140,7 +138,7 @@ bool fk_UniChar::IsAscii(void)
 	return false;
 }
 
-char fk_UniChar::GetAscii(void)
+char fk_UniChar::getAscii(void)
 {
 	return char(code);
 }
@@ -218,7 +216,7 @@ bool fk_UniStr::fgetLine(FILE *argFP, fk_StringCode argCode)
 	return true;
 }
 
-void fk_UniStr::convert(const string argStr, fk_StringCode argCode)
+void fk_UniStr::convert(const string &argStr, fk_StringCode argCode)
 {
 	unsigned int		i;
 	fk_UniChar			uniChar;
@@ -227,22 +225,22 @@ void fk_UniStr::convert(const string argStr, fk_StringCode argCode)
 	  case FK_STR_UTF16:
 		clear();
 		for(i = 0; i < argStr.size(); i += 2) {
-			uniChar.SetBuffer((unsigned char)argStr[i],
+			uniChar.setBuffer((unsigned char)argStr[i],
 							  (unsigned char)argStr[i+1]);
 			push_back(&uniChar);
 		}
 		break;
 
 	  case FK_STR_JIS:
-		strConverter.ConvertJIS(argStr, this);
+		strConverter.convertJIS(argStr, this);
 		break;
 
 	  case FK_STR_SJIS:
-		strConverter.ConvertSJIS(argStr, this);
+		strConverter.convertSJIS(argStr, this);
 		break;
 
 	  case FK_STR_EUC:
-		strConverter.ConvertEUC(argStr, this);
+		strConverter.convertEUC(argStr, this);
 		break;
 
 	  default:
@@ -265,19 +263,19 @@ bool fk_UniStr::fgetLine_UTF16(FILE *argFP)
 
 	do {
 
-		uniChar.SetBuffer(buffer[0], buffer[1]);
-		if(uniChar.GetCode() == 10) {	// CR
+		uniChar.setBuffer(buffer[0], buffer[1]);
+		if(uniChar.getCode() == 10) {	// CR
 			if(getLength() != 0) {
 				if(getCode(getLength()-1) == 13) {
 					pop_back();
 				}
 			}
-			push_back(uniChar.GetCode());
+			push_back(uniChar.getCode());
 			break;
 		}
 
-		if(uniChar.GetCode() != 65279) {
-			push_back(uniChar.GetCode());
+		if(uniChar.getCode() != 65279) {
+			push_back(uniChar.getCode());
 		}
 
 	} while(fread((char *)buffer, sizeof(unsigned char), 2, argFP) == 2);
@@ -296,7 +294,7 @@ bool fk_UniStr::readFile(string argFileName, fk_StringCode argCode)
 
 	clear();
 
-	while(fgetLine(fp, argCode) == true);
+	while(fgetLine(fp, argCode) == true) {};
 	fclose(fp);
 
 	return true;
@@ -311,6 +309,20 @@ int fk_UniStr::getCode(int argID) const
 	return uniStr[argID];
 }
 
+void fk_UniStr::printf(fk_StringCode argCode, const char *argFormat, ...)
+{
+	va_list		ap;
+	char		buffer[65536];
+	string		str;
+
+	va_start(ap, argFormat);
+	vsnprintf(buffer, 65535, argFormat, ap);
+	va_end(ap);
+	str = buffer;
+	convert(buffer, argCode);
+	return;
+}
+
 int fk_UniStr::find(int argStart, int argCode)
 {
 	int				i;
@@ -348,13 +360,13 @@ void fk_UniStr::push_back(fk_UniChar *argUC)
 {
 	if(argUC == (fk_UniChar *)NULL) return;
 
-	uniStr.push_back(argUC->GetCode());
+	uniStr.push_back(argUC->getCode());
 	return;
 }
 
 void fk_UniStr::push_back(fk_UniChar argUC)
 {
-	uniStr.push_back(argUC.GetCode());
+	uniStr.push_back(argUC.getCode());
 	return;
 }
 
@@ -378,7 +390,7 @@ void fk_UniStr::copyStr(fk_UniStr *argStr)
 	return;
 }
 
-void fk_UniStr::print(string argStr)
+void fk_UniStr::Print(string argStr)
 {
 	string	prefix;
 	int		i;
@@ -515,7 +527,7 @@ void fk_StrConverter::CommonConvert(ImdKanjiCodeConverter *argKCV,
 		dummy = 0;
 		size = argKCV->execute(argStr[i], buffer, &dummy);
 		for(j = 0; j < size; j += 2) {
-			uniChar.SetBuffer(buffer[j], buffer[j+1]);
+			uniChar.setBuffer(buffer[j], buffer[j+1]);
 			outStr->push_back(&uniChar);
 		}
 	}
@@ -523,7 +535,7 @@ void fk_StrConverter::CommonConvert(ImdKanjiCodeConverter *argKCV,
 	return;
 }
 
-void fk_StrConverter::ConvertJIS(const string &argStr, fk_UniStr *outStr)
+void fk_StrConverter::convertJIS(const string &argStr, fk_UniStr *outStr)
 {
 	if(jisBase == (ImdKanjiCodeConverter *)NULL) {
 		InitJISBase();
@@ -533,7 +545,7 @@ void fk_StrConverter::ConvertJIS(const string &argStr, fk_UniStr *outStr)
 	return;
 }
 
-void fk_StrConverter::ConvertSJIS(const string &argStr, fk_UniStr *outStr)
+void fk_StrConverter::convertSJIS(const string &argStr, fk_UniStr *outStr)
 {
 	if(sjisBase == (ImdKanjiCodeConverter *)NULL) {
 		InitSJISBase();
@@ -543,7 +555,7 @@ void fk_StrConverter::ConvertSJIS(const string &argStr, fk_UniStr *outStr)
 	return;
 }
 
-void fk_StrConverter::ConvertEUC(const string &argStr, fk_UniStr *outStr)
+void fk_StrConverter::convertEUC(const string &argStr, fk_UniStr *outStr)
 {
 	if(eucBase == (ImdKanjiCodeConverter *)NULL) {
 		InitEUCBase();
