@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,7 +71,7 @@
  ****************************************************************************/
 #include <FK/ShapeViewer.h>
 #include <FK/Vertex.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 #include <FL/Fl_Menu_Bar.H>
 #include <FL/Fl_Value_Slider.H>
@@ -148,7 +146,7 @@ static void LocalMenuToggle(Fl_Widget *argW, void *)
 	const Fl_Menu_Item	*mItem = mw->mvalue();
 	string				labelString;
 
-	if(mItem == (Fl_Menu_Item *)NULL) return;
+	if(mItem == NULL) return;
 	labelString = mItem->label();
 	if(labelString == "WRL&Open") {
 		globalMenuStatus = FK_SV_GUI_WRLOPEN;
@@ -275,7 +273,7 @@ void fk_ShapeViewer::SetMaterial(int id, fk_ShapeGUIMenuItem index,
 fk_ShapeViewer::fk_ShapeViewer(int argW, int argH)
 	: fk_BaseObject(FK_SHAPEVIEWER)
 {
-	fk_InitMaterial();
+	fk_Material::initDefault();
 
 	gui = new fk_GUI_();
 	InitValue();
@@ -300,8 +298,8 @@ fk_ShapeViewer::~fk_ShapeViewer()
 
 void fk_ShapeViewer::InitValue(void)
 {
-	mainWindow = (Fl_Window *)NULL;
-	viewWin = (fk_Window *)NULL;
+	mainWindow = NULL;
+	viewWin = NULL;
 
 	mouseX = mouseY = -1;
 
@@ -316,7 +314,7 @@ void fk_ShapeViewer::InitWindow(void)
 
 	head = pitch = bank = scale = axisScale = 0.0;
 
-	if(mainWindow != (Fl_Window *)NULL) {
+	if(mainWindow != NULL) {
 		head = getHead();
 		pitch = getPitch();
 		bank = getBank();
@@ -477,8 +475,8 @@ void fk_ShapeViewer::AxisInit(void)
 	axisLine.setPalette(localGreen, 1);
 	axisLine.setPalette(localCyan, 2);
 
-	curE = axisLine.getNextE((fk_Edge *)NULL);
-	while(curE != (fk_Edge *)NULL) {
+	curE = axisLine.getNextE(NULL);
+	while(curE != NULL) {
 		rPos = axisLine.getRightVOnE(curE)->getPosition();
 		lPos = axisLine.getLeftVOnE(curE)->getPosition();
 
@@ -604,8 +602,8 @@ void fk_ShapeViewer::ModelInit(int argIndex, fk_Shape *argShape)
 		localModel = modelArray[trueID];
 	}
 
-	if(argShape == (fk_Shape *)NULL) {
-		localModel->setShape((fk_Shape *)NULL);
+	if(argShape == NULL) {
+		localModel->setShape(NULL);
 		return;
 	}
 
@@ -683,7 +681,7 @@ string fk_ShapeViewer::CommonFileChooser(string argFil, int argMode,
 	}
 
 	fCharP = fc->value(1);
-	if(fCharP == (const char *)NULL) {
+	if(fCharP == NULL) {
 		return fileName;
 	}
 
@@ -767,7 +765,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 
 		if(fileName.length() == 0) break;
 
-		if((fp = fopen(fileName.c_str(), "r")) != (FILE *)NULL) {
+		if((fp = fopen(fileName.c_str(), "r")) != NULL) {
 			fclose(fp);
 			if(fl_choice("OverWrite?", NULL, "No", "Yes") == 1) {
 				break;
@@ -775,7 +773,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 		}
 
 		shape = getShape(0);
-		if(shape == (fk_Shape *)NULL) break;
+		if(shape == NULL) break;
 
 		switch(shape->getObjectType()) {
 		  case FK_SOLID:
@@ -815,9 +813,9 @@ bool fk_ShapeViewer::MenuSelect(void)
 		if(fileName.length() == 0) break;
 
 		shape = getShape(0);
-		if(shape == (fk_Shape *)NULL) break;
+		if(shape == NULL) break;
 
-		if((fp = fopen(fileName.c_str(), "r")) != (FILE *)NULL) {
+		if((fp = fopen(fileName.c_str(), "r")) != NULL) {
 			fclose(fp);
 			if(fl_choice("OverWrite?", NULL, "No", "Yes") == 1) {
 				break;
@@ -839,7 +837,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 
 		if(fileName.length() == 0) break;
 
-		if((fp = fopen(fileName.c_str(), "r")) != (FILE *)NULL) {
+		if((fp = fopen(fileName.c_str(), "r")) != NULL) {
 			fclose(fp);
 			if(fl_choice("OverWrite?", NULL, "No", "Yes") == 1) {
 				break;
@@ -896,7 +894,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 		shininess = polyMaterial[0]->getShininess();
 		str = fl_input("Please input Shininess Value.",
 					   fk_StrPrintf("%lf", shininess).c_str());
-		if(str == (const char *)NULL) break;
+		if(str == NULL) break;
 		shininess = atof(str);
 		if(shininess >= 1.0 || shininess <= 128.0) {
 			for(i = 0; i < getModelNum(); i++) {
@@ -958,6 +956,7 @@ void fk_ShapeViewer::DragShape(void)
 {
 	double	oldX, oldY;
 
+	if(viewWin == NULL) return;
 	if(viewWin->getMouseStatus(FK_MOUSE1) == true) {
 		moveFlag = true;
 		oldX = mouseX;
@@ -976,6 +975,8 @@ void fk_ShapeViewer::DragShape(void)
 
 void fk_ShapeViewer::KeyHandle(void)
 {
+	if(viewWin == NULL) return;
+
 	if(viewWin->getKeyStatus(' ', false) == true) {
 		if(viewWin->getSpecialKeyStatus(FK_SHIFT_R, false) == true ||
 		   viewWin->getSpecialKeyStatus(FK_SHIFT_L, false) == true) {
@@ -1000,6 +1001,8 @@ bool fk_ShapeViewer::draw(void)
 {
 	bool	loopFlg;
 
+	if(mainWindow == NULL || viewWin == NULL) return false;
+
 	if(MenuSelect() == false) {
 		return false;
 	}
@@ -1051,8 +1054,8 @@ void fk_ShapeViewer::setWindowSize(int argW, int argH)
 
 void fk_ShapeViewer::setShape(int argIndex, fk_Shape *argShape)
 {
-	if(argShape == (fk_Shape *)NULL) {
-		ModelInit(argIndex, (fk_Shape *)NULL);
+	if(argShape == NULL) {
+		ModelInit(argIndex, NULL);
 		return;
 	}
 
@@ -1122,14 +1125,14 @@ void fk_ShapeViewer::SetDrawMode(void)
 
 void fk_ShapeViewer::setFrameMode(fk_FrameMode argMode)
 {
-	if(viewWin == (fk_Window *)NULL) return;
+	if(viewWin == NULL) return;
 	viewWin->setFrameMode(argMode);
 	return;
 }
 
 void fk_ShapeViewer::setFrameInterval(int argInterval)
 {
-	if(viewWin == (fk_Window *)NULL) return;
+	if(viewWin == NULL) return;
 	viewWin->setFrameInterval(argInterval);
 	return;
 }
@@ -1146,6 +1149,11 @@ void fk_ShapeViewer::setBGColor(float argR, float argG, float argB)
 	return;
 }
 
+fk_Color fk_ShapeViewer::getBGColor(void)
+{
+	return scene.getBGColor();
+}
+
 void fk_ShapeViewer::setHead(double argVal)
 {
 	int		div;
@@ -1364,7 +1372,7 @@ int fk_ShapeViewer::getModelNum(void)
 fk_Shape * fk_ShapeViewer::getShape(int argID)
 {
 	if(IDMap.find(argID) == IDMap.end()) {
-		return (fk_Shape *)NULL;
+		return(NULL);
 	}
 
 	return modelArray[IDMap[argID]]->getShape();
@@ -1392,16 +1400,22 @@ fk_DrawMode fk_ShapeViewer::getDrawMode(int argID)
 
 fk_FrameMode fk_ShapeViewer::getFrameMode(void)
 {
-	if(viewWin == (fk_Window *)NULL) return FK_DEFAULT_FRAME;
+	if(viewWin == NULL) return FK_DEFAULT_FRAME;
 	return viewWin->getFrameMode();
 }
 
 int fk_ShapeViewer::getFrameInterval(void)
 {
-	if(viewWin == (fk_Window *)NULL) return 0;
+	if(viewWin == NULL) return 0;
 	return viewWin->getFrameInterval();
 }
 
+int fk_ShapeViewer::getSkipFrame(void)
+{
+	if(viewWin == NULL) return 0;
+	return viewWin->getSkipFrame();
+}
+
 double fk_ShapeViewer::getHead(void)
 {
 	return gui->headSlider->value();
@@ -1465,14 +1479,17 @@ bool fk_ShapeViewer::shapeProcess(fk_Solid *)
 	return true;
 }
 
-bool fk_ShapeViewer::snapImage(const string argFName)
+bool fk_ShapeViewer::snapImage(string argFName, fk_ImageType argFormat,
+							   fk_SnapProcMode argMode)
 {
-	return viewWin->snapImage(argFName);
+	if(viewWin == NULL) return false;
+	return viewWin->snapImage(argFName, argFormat, argMode);
 }
 
-bool fk_ShapeViewer::snapImage(fk_Image *argImage)
+bool fk_ShapeViewer::snapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 {
-	return viewWin->snapImage(argImage);
+	if(viewWin == NULL) return false;
+	return viewWin->snapImage(argImage, argMode);
 }
 
 void fk_ShapeViewer::setPutStrMode(const fk_PutStrMode argMode)
