@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -78,7 +76,7 @@
 #include <FK/Window.h>
 #include <FK/Image.h>
 #include <FL/Fl.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <FL/Fl_Multi_Browser.h>
 #include <FL/x.h>
 #include <iostream>
@@ -314,10 +312,10 @@ bool fk_Window::setPutFile(const string &argFileName)
 void fk_Window::printf(const char *argFormat, ...)
 {
 	va_list		ap;
-	char		buffer[1024];
+	char		buffer[65536];
 
 	va_start(ap, argFormat);
-	vsnprintf(buffer, 1023, argFormat, ap);
+	vsnprintf(buffer, 65535, argFormat, ap);
 	va_end(ap);
 	putString(buffer);
 	return;
